# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{last_name}}, {{first_name}}',
    )

    first_names = (
        'Ādams', 'Ādolfs', 'Agris', 'Aigars', 'Ainārs', 'Aivars', 'Alberts',
        'Aldis', 'Aleksandrs', 'Alfrēds', 'Andrejs', 'Andris', 'Andrešs', 'Ansis',
        'Antons', 'Armands', 'Arnis', 'Arnolds', 'Artis', 'Arturs', 'Artūrs', 'Arvīds',
        'Augusts', 'Bērends', 'Bērtulis', 'Brencis', 'Dainis', 'Daniels', 'Dāvis',
        'Dzintars', 'Edgars', 'Edmunds', 'Eduards', 'Edvīns', 'Egils', 'Elmārs', 'Elvis',
        'Emīls', 'Ēriks', 'Ermanis', 'Ernests', 'Ēvalds', 'Fricis', 'Gatis', 'Gunārs',
        'Guntars', 'Guntis', 'Ģederts', 'Ģirts', 'Hanss', 'Harijs', 'Henriks', 'Hermanis',
        'Igors', 'Ilmārs', 'Imants', 'Indriķis', 'Ivars', 'Ivo', 'Jakobs', 'Janis', 'Jānis',
        'Jannis', 'Jāzeps', 'Jēkabs', 'Jēkaubs', 'Jezups', 'Johans', 'Jūlijs', 'Juris', 'Kārlis',
        'Kaspars', 'Konradus', 'Kristaps', 'Kristers', 'Krists', 'Krišjānis', 'Krišs', 'Laimonis',
        'Lauris', 'Leons', 'Macs', 'Mareks', 'Māris', 'Mārtiņš', 'Matīss', 'Mihels', 'Mikels',
        'Miķelis', 'Modris', 'Nikolajs', 'Niks', 'Normunds', 'Oļģerts', 'Oskars', 'Osvalds',
        'Oto', 'Pauls', 'Pēteris', 'Raimonds', 'Raivis', 'Reinis', 'Ričards', 'Rihards', 'Roberts',
        'Rolands', 'Rūdolfs', 'Sandis', 'Staņislavs', 'Tenis', 'Teodors', 'Toms', 'Uldis', 'Valdis',
        'Viesturs', 'Viktors', 'Vilis', 'Vilnis', 'Viļums', 'Visvaldis', 'Vladislavs', 'Voldemārs',
        'Ziedonis', 'Žanis', 'Agnese', 'Aiga', 'Aija', 'Aina', 'Alīda', 'Alise', 'Alma', 'Alvīne',
        'Amālija', 'Anete', 'Anita', 'Anna', 'Annija', 'Antoņina', 'Antra', 'Ārija', 'Ausma', 'Austra',
        'Baba', 'Baiba', 'Berta', 'Biruta', 'Broņislava', 'Dace', 'Daiga', 'Daina', 'Dārta', 'Diāna',
        'Doroteja', 'Dzidra', 'Dzintra', 'Eda', 'Edīte', 'Elīna', 'Elita', 'Elizabete', 'Elvīra', 'Elza',
        'Emīlija', 'Emma', 'Ērika', 'Erna', 'Eva', 'Evija', 'Evita', 'Gaida', 'Genovefa', 'Grēta', 'Grieta',
        'Gunita', 'Gunta', 'Helēna', 'Ieva', 'Ilga', 'Ilona', 'Ilze', 'Ina', 'Ināra', 'Indra', 'Inese', 'Ineta',
        'Inga', 'Ingrīda', 'Inguna', 'Inta', 'Irēna', 'Irma', 'Iveta', 'Jana', 'Janina', 'Jūle', 'Jūla',
        'Jūlija', 'Karina', 'Karlīna', 'Katarīna', 'Katrīna', 'Krista', 'Kristiāna', 'Laila', 'Laura',
        'Lavīze', 'Leontīne', 'Lība', 'Lidija', 'Liene', 'Līga', 'Ligita', 'Lilija', 'Lilita', 'Līna',
        'Linda', 'Līza', 'Lizete', 'Lūcija', 'Madara', 'Made', 'Maija', 'Māra', 'Mare', 'Margareta', 'Margrieta',
        'Marija', 'Mārīte', 'Marta', 'Maža', 'Milda', 'Minna', 'Mirdza', 'Monika', 'Natālija', 'Olga', 'Otīlija',
        'Paula', 'Paulīna', 'Rasma', 'Regīna', 'Rita', 'Rudīte', 'Ruta', 'Rute', 'Samanta', 'Sandra', 'Sanita',
        'Santa', 'Sapa', 'Sarmīte', 'Silvija', 'Sintija', 'Skaidrīte', 'Solvita', 'Tekla', 'Trīne', 'Valda',
        'Valentīna', 'Valija', 'Velta', 'Veneranda', 'Vera', 'Veronika', 'Vija', 'Vilma', 'Vineta', 'Vita', 'Zane',
        'Zelma', 'Zenta', 'Zigrīda',
    )

    last_names = (
        'Ābele',
        'Āboliņš',
        'Ābols',
        'Alksnis',
        'Apinis',
        'Apsītis',
        'Auniņš',
        'Auziņš',
        'Avotiņš',
        'Balodis',
        'Baltiņš',
        'Bērziņš',
        'Birznieks',
        'Bite',
        'Briedis',
        'Caune',
        'Celmiņš',
        'Celms',
        'Cīrulis',
        'Dzenis',
        'Dūmiņš',
        'Eglītis',
        'Jaunzems',
        'Kalējs',
        'Kalniņš',
        'Kaņeps',
        'Kārkliņš',
        'Kauliņš',
        'Kļaviņš',
        'Krastiņš',
        'Krēsliņš',
        'Krieviņš',
        'Krievs',
        'Krūmiņš',
        'Krūze',
        'Kundziņš',
        'Lācis',
        'Lagzdiņš',
        'Lapsa',
        'Līcis',
        'Liepa',
        'Liepiņš',
        'Lukstiņš',
        'Lūsis',
        'Paegle',
        'Pērkons',
        'Podnieks',
        'Polis',
        'Priede',
        'Priedītis',
        'Puriņš',
        'Purmals',
        'Riekstiņš',
        'Roze',
        'Rozītis',
        'Rubenis',
        'Rudzītis',
        'Saulītis',
        'Siliņš',
        'Skuja',
        'Skujiņš',
        'Sproģis',
        'Strazdiņš',
        'Turiņš',
        'Vanags',
        'Vīksna',
        'Vilciņš',
        'Vilks',
        'Vītoliņš',
        'Vītols',
        'Zaķis',
        'Zālītis',
        'Zariņš',
        'Zeltiņš',
        'Ziemelis',
        'Zirnis',
        'Zvaigzne',
        'Zvirbulis')



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}',
    )
    first_names = (
        'Alexander', 'Alina', 'Andreas', 'Anna', 'Anton',
        'Benjamin', 'Bernhard',
        'Christian', 'Christop',
        'Daniel', 'David', 'Dominik',
        'Elena', 'Elias', 'Emil', 'Emilia',
        'Fabian', 'Felix', 'Florian', 'Franz', 'Fransizka',
        'Gabriel', 'Gernot',
        'Hanna',
        'Ingrid', 'Isabel',
        'Jakob', 'Jana', 'Jasmin', 'Johanna', 'Johannes', 'Jonas', 'Julia', 'Julian',
        'Katharinna', 'Konrad', 'Konstantin',
        'Lara', 'Laura', 'Lena', 'Leo', 'Leon', 'Linda', 'Luca', 'Lukas',
        'Marcel', 'Maria', 'Martin', 'Matthias', 'Max', 'Maximilian', 'Mia', 'Michael', 'Moritz',
        'Nico', 'Niklas', 'Nina', 'Noah',
        'Oliver', 'Olivia',
        'Paul', 'Paula', 'Philipp', 'Pia',
        'Raphael', 'Robert',
        'Samuel', 'Sarah', 'Sebastian', 'Simon', 'Sophie',
        'Theresa', 'Thomas', 'Tim',
        'Tobias',
        'Valentin',
    )
    last_names = (
        'Auer', 'Aigner',
        'Bauer', 'Baumgartner', 'Berger', 'Binder', 'Brunner',
        'Cap', 'Capek', 'Cech', 'Chum',
        'Deng', 'Denk', 'Daume', 'Dienstl',
        'Ebner', 'Eder', 'Egger',
        'Fasching', 'Felber', 'Ferstel', 'Fichtner', 'Fischer', 'Fuchs',
        'Gasser', 'Gastegger', 'Geier', 'Geisler', 'Grabner', 'Gruber',
        'Haas', 'Haiden', 'Hofer', 'Holzer', 'Huber',
        'Illes', 'Ircher', 'Itzlinger',
        'Jahn', 'Jobst', 'Jung', 'Jungbauer', 'Just',
        'Kainz', 'Karl', 'Karner', 'Koller',
        'Lang', 'Lechner', 'Lehner', 'Leitner',
        'Maier', 'Mair', 'Maurer', 'Mayer', 'Mayr', 'Moser', 'Müllner',
        'Pichler', 'Pucher',
        'Reiter', 'Riegler',
        'Schmid', 'Schneider', 'Schuster', 'Schwarz', 'Stadler', 'Steiner',
        'Wallner', 'Weber', 'Weiss', 'Wieser', 'Wimmer', 'Winkler', 'Winter', 'Wolf',
    )

    prefixes = ('Dr.', 'Mag.', 'Ing.', 'Dipl.-Ing.', 'Prof.', 'Univ.Prof.')



# coding=utf-8
from __future__ import unicode_literals


from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    DAY_NAMES = {
        '0': 'السبت',
        '1': 'الأحد',
        '2': 'الإثنين',
        '3': 'الثلاثاء',
        '4': 'الأربعاء',
        '5': 'الخميس',
        '6': 'الجمعة',
    }

    MONTH_NAMES = {
        '01': 'كانون الثّاني',
        '02': 'شباط',
        '03': 'آذار',
        '04': 'نيسان',
        '05': 'أيّار',
        '06': 'حزيران',
        '07': 'تمّوز',
        '08': 'آب',
        '09': 'أيلول',
        '10': 'تشرين الأول',
        '11': 'تشرين الثاني',
        '12': 'كانون الأول',
    }

    centuries = [
        'الأول', 'الثاني', 'الثالث', 'الرابع', 'الخامس', 'السادس',
        'السابع', 'الثامن', 'التاسع', 'العاشر', 'الحادي عشر',
        'الثاني عشر', 'الثالث عشر', 'الرابع عشر', 'الخامس عشر',
        'السادس عشر', 'الثامن عشر', 'التاسع عشر', 'العشرين',
        'الحادي والعشرين', 'الثاني والعشرين',
    ]

    countries = [{'timezones': ['أوروب/أندورا'],
                  'alpha-2-code': 'AD',
                  'continent': 'أوروبا',
                  'name': 'أندورا',
                  'capital': 'أندورا لا فيلا'},
                 {'timezones': ['آسيا/كابل'],
                  'alpha-2-code': 'AF',
                  'continent': 'آسيا',
                  'name': 'أفغانستان',
                  'capital': 'كابل'},
                 {'timezones': ['أمريكا/أنتيغوا'],
                  'alpha-2-code': 'AG',
                  'continent': 'أمريكا الشمالية',
                  'name': 'أنتيغوا وباربودا',
                  'capital': "سانت جونز"},
                 {'timezones': ['أوروبا/تيرانا'],
                  'alpha-2-code': 'AL',
                  'continent': 'أوروبا',
                  'name': 'ألبانيا',
                  'capital': 'تيرانا'},
                 {'timezones': ['آسيا/يريفان'],
                  'alpha-2-code': 'AM',
                  'continent': 'آسيا',
                  'name': 'أرمينيا',
                  'capital': 'يريفان'},
                 {'timezones': ['إفريقيا/لواندا'],
                  'alpha-2-code': 'AO',
                  'continent': 'إفريقيا',
                  'name': 'أنغولا',
                  'capital': 'لواندا'},
                 {'timezones': ['أمريكا/الأرجنتين/بوينس_آيرس',
                                'أمريكا/الأرجنتين/Cordoba',
                                'أمريكا/الأرجنتين/خوخوي',
                                'أمريكا/الأرجنتين/توكومان',
                                'أمريكا/الأرجنتين/كاتاماركا',
                                'أمريكا/الأرجنتين/لا_ريوخا',
                                'أمريكا/الأرجنتين/سان_خوان',
                                'أمريكا/الأرجنتين/مندوزا',
                                'أمريكا/الأرجنتين/ريو_غاليغوس',
                                'أمريكا/الأرجنتين/أوشوايا'],
                  'alpha-2-code': 'AR',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'الأرجنتين',
                  'capital': 'بوينس آيرس'},
                 {'timezones': ['أوروبا/النمسا'],
                  'alpha-2-code': 'AT',
                  'continent': 'أوروبا',
                  'name': 'النمسا',
                  'capital': 'فيينا'},
                 {'timezones': ['أستراليا/لورد_هاو',
                                'أستراليا/هوبارت',
                                'أستراليا/كري',
                                'أستراليا/ملبورن',
                                'أستراليا/سدني',
                                'أستراليا/بروكن_هل',
                                'أستراليا/بريزبن',
                                'أستراليا/ليندمان',
                                'أستراليا/أديلايد',
                                'أستراليا/داروين',
                                'أستراليا/برث'],
                  'alpha-2-code': 'AU',
                  'continent': 'أوقيانوسيا',
                  'name': 'أستراليا',
                  'capital': 'كانبرا'},
                 {'timezones': ['آسيا/باكو'],
                  'alpha-2-code': 'AZ',
                  'continent': 'آسيا',
                  'name': 'أذربيجان',
                  'capital': 'باكو'},
                 {'timezones': ['أمريكا/باربادوس'],
                  'alpha-2-code': 'BB',
                  'continent': 'أمريكا الشمالية',
                  'name': 'باربادوس',
                  'capital': 'بريدج تاون'},
                 {'timezones': ['آسيا/دكا'],
                  'alpha-2-code': 'BD',
                  'continent': 'آسيا',
                  'name': 'بنغلادش',
                  'capital': 'دكا'},
                 {'timezones': ['أوروبا/بروكسل'],
                  'alpha-2-code': 'BE',
                  'continent': 'أوروبا',
                  'name': 'بلجيكا',
                  'capital': 'بروكسل'},
                 {'timezones': ['إفريقيا/واغادوغو'],
                  'alpha-2-code': 'BF',
                  'continent': 'إفريقيا',
                  'name': 'بوركينا فاسو',
                  'capital': 'واغادوغو'},
                 {'timezones': ['أوروبا/صوفيا'],
                  'alpha-2-code': 'BG',
                  'continent': 'أوروبا',
                  'name': 'بلغاريا',
                  'capital': 'صوفيا'},
                 {'timezones': ['آسيا/البحرين'],
                  'alpha-2-code': 'BH',
                  'continent': 'آسيا',
                  'name': 'البحرين',
                  'capital': 'المنامة'},
                 {'timezones': ['إفريقيا/بوجمبورا'],
                  'alpha-2-code': 'BI',
                  'continent': 'إفريقيا',
                  'name': 'بوروندي',
                  'capital': 'بوجمبورا'},
                 {'timezones': ['إفريقيا/بورتو نوفو'],
                  'alpha-2-code': 'BJ',
                  'continent': 'إفريقيا',
                  'name': 'بنين',
                  'capital': 'بورتو نوفو'},
                 {'timezones': ['آسيا/بروناي'],
                  'alpha-2-code': 'BN',
                  'continent': 'آسيا',
                  'name': 'اتحاد بروناي (دار السلام)',
                  'capital': 'بندر سري بكاوان'},
                 {'timezones': ['أمريكا/لاباز'],
                  'alpha-2-code': 'BO',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'بوليفيا',
                  'capital': 'سوكري'},
                 {'timezones': ['أمريكا/نورونها',
                                'أمريكا/بليم',
                                'أمريكا/فورتاليزا',
                                'أمريكا/ريسيفي',
                                'أمريكا/أراغوينا',
                                'أمريكا/ماسايو',
                                'أمريكا/باهيا',
                                'أمريكا/ساو_باولو',
                                'أمريكا/كامبو_غراندي',
                                'أمريكا/كويابا',
                                'أمريكا/بورتو_فاليو',
                                'أمريكا/بوا_فيستا',
                                'أمريكا/ماناوس',
                                'أمريكا/إيرونيبي',
                                'أمريكا/ريو_برانكو'],
                  'alpha-2-code': 'BR',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'البرازيل',
                  'capital': 'برازيليا'},
                 {'timezones': ['أمريكا/ناساو'],
                  'alpha-2-code': 'BS',
                  'continent': 'أمريكا الشمالية',
                  'name': 'باهاماس',
                  'capital': 'ناساو'},
                 {'timezones': ['آسيا/تيمفو'],
                  'alpha-2-code': 'BT',
                  'continent': 'آسيا',
                  'name': 'بوتان',
                  'capital': 'تيمفو'},
                 {'timezones': ['إفريقيا/غابورون'],
                  'alpha-2-code': 'BW',
                  'continent': 'إفريقيا',
                  'name': 'بوتسوانا',
                  'capital': 'غابورون'},
                 {'timezones': ['أوروبا/مينسك'],
                  'alpha-2-code': 'BY',
                  'continent': 'أوروبا',
                  'name': 'روسيا البيضاء',
                  'capital': 'مينسك'},
                 {'timezones': ['أمريكا/بليز'],
                  'alpha-2-code': 'BZ',
                  'continent': 'أمريكا الشمالية',
                  'name': 'بليز',
                  'capital': 'بلموبان'},
                 {'timezones': ['أمريكا/سينت_جونز',
                                'أمريكا/هاليفاكس',
                                'أمريكا/جليس_باي',
                                'أمريكا/مونكتون',
                                'أمريكا/جووس_باي',
                                'أمريكا/بلانك_سابلون',
                                'أمريكا/مونتريال',
                                'أمريكا/تورونتو',
                                'أمريكا/نيبيغون',
                                'أمريكا/ثاندر_باي',
                                'أمريكا/بانغيرتانغ',
                                'أمريكا/إيكواليوت',
                                'أمريكا/أتيكوكان',
                                'أمريكا/رانكن_إنلت',
                                'أمريكا/وينيبيغ',
                                'أمريكا/رايني_ريفر',
                                'أمريكا/كامبريدج_باي',
                                'أمريكا/ريجينا',
                                'أمريكا/سويفت_كارنت',
                                'أمريكا/إدمونتون',
                                'أمريكا/يلو_نايف',
                                'أمريكا/إنوفك',
                                'أمريكا/دوسن_كريك',
                                'أمريكا/فانكوفر',
                                'أمريكا/وايت_هورس',
                                'أمريكا/داوسون'],
                  'alpha-2-code': 'CA',
                  'continent': 'أمريكا الشمالية',
                  'name': 'كندا',
                  'capital': 'أوتاوا'},
                 {'timezones': ['إفريقيا/كينشاسا',
                                'إفريقيا/لوبومباشي'],
                  'alpha-2-code': 'CD',
                  'continent': 'إفريقيا',
                  'name': 'جمهورية الكونغو الديمقراطية',
                  'capital': 'كينشاسا'},
                 {'timezones': ['إفريقيا/برازافيل'],
                  'alpha-2-code': 'CG',
                  'continent': 'إفريقيا',
                  'name': 'جمهورية الكونغو',
                  'capital': 'برازافيل'},
                 {'timezones': ['إفريقيا/أبيدجان'],
                  'alpha-2-code': 'CI',
                  'continent': 'إفريقيا',
                  'name': "ساحل العاج",
                  'capital': 'ياموسوكرو'},
                 {'timezones': ['أمريكا/سانتياغو',
                                'المحيط_الهاديء/جزيرة_القيامة'],
                  'alpha-2-code': 'CL',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'تشيلي',
                  'capital': 'سانتياغو'},
                 {'timezones': ['إفريقيا/دوالا'],
                  'alpha-2-code': 'CM',
                  'continent': 'إفريقيا',
                  'name': 'الكاميرون',
                  'capital': 'ياوندي'},
                 {'timezones': ['آسيا/شانغهاي',
                                'آسيا/هاربن',
                                'آسيا/تشونغتشينغ',
                                'آسيا/أورومتشي',
                                'آسيا/كاشغر'],
                  'alpha-2-code': 'CN',
                  'continent': 'آسيا',
                  'name': "جمهورية الصين الشعبية",
                  'capital': 'بكين'},
                 {'timezones': ['أمريكا/بوغوتا'],
                  'alpha-2-code': 'CO',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'كولومبيا',
                  'capital': 'بوغوتا'},
                 {'timezones': ['أمريكا/كوستاريكا'],
                  'alpha-2-code': 'CR',
                  'continent': 'أمريكا الشمالية',
                  'name': 'كوستاريكا',
                  'capital': 'سان خوسيه'},
                 {'timezones': ['أمريكا/هافانا'],
                  'alpha-2-code': 'CU',
                  'continent': 'أمريكا الشمالية',
                  'name': 'كوبا',
                  'capital': 'هافانا'},
                 {'timezones': ['الأطلنطي/الرأس_الأخضر'],
                  'alpha-2-code': 'CV',
                  'continent': 'إفريقيا',
                  'name': 'جمهورية الرأس الأخضر',
                  'capital': 'برايا'},
                 {'timezones': ['آسيا/نيقوسيا'],
                  'alpha-2-code': 'CY',
                  'continent': 'آسيا',
                  'name': 'قبرص',
                  'capital': 'نيقوسيا'},
                 {'timezones': ['أوروبا/براغ'],
                  'alpha-2-code': 'CZ',
                  'continent': 'أوروبا',
                  'name': 'جمهورية التشيك',
                  'capital': 'براغ'},
                 {'timezones': ['أوروبا/برلين'],
                  'alpha-2-code': 'DE',
                  'continent': 'أوروبا',
                  'name': 'ألمانيا',
                  'capital': 'برلين'},
                 {'timezones': ['إفريقيا/جيبوتي'],
                  'alpha-2-code': 'DJ',
                  'continent': 'إفريقيا',
                  'name': 'جيبوتي',
                  'capital': 'جيبوتي'},
                 {'timezones': ['أوروبا/كوبنهاغن'],
                  'alpha-2-code': 'DK',
                  'continent': 'أوروبا',
                  'name': 'الدنمارك',
                  'capital': 'كوبنهاغن'},
                 {'timezones': ['أمريكا/دومينيكا'],
                  'alpha-2-code': 'DM',
                  'continent': 'أمريكا الشمالية',
                  'name': 'دومينيكا',
                  'capital': 'روسياو'},
                 {'timezones': ['أمريكا/سانتو_دومينغو'],
                  'alpha-2-code': 'DO',
                  'continent': 'أمريكا الشمالية',
                  'name': 'جمهورية الدومينيكان',
                  'capital': 'سانتو دومينغو'},
                 {'timezones': ['أمريكا/غواياكيل',
                                'المحيط_الهاديء/أرخبيل_غالاباغوس'],
                  'alpha-2-code': 'EC',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'الإكوادور',
                  'capital': 'كيتو'},
                 {'timezones': ['أوروبا/تالين'],
                  'alpha-2-code': 'EE',
                  'continent': 'أوروبا',
                  'name': 'إستونيا',
                  'capital': 'تالين'},
                 {'timezones': ['إفريقيا/القاهرة'],
                  'alpha-2-code': 'EG',
                  'continent': 'إفريقيا',
                  'name': 'مصر',
                  'capital': 'القاهرة'},
                 {'timezones': ['إفريقيا/أسمرة'],
                  'alpha-2-code': 'ER',
                  'continent': 'إفريقيا',
                  'name': 'إرتيريا',
                  'capital': 'أسمرة'},
                 {'timezones': ['إفريقيا/أديس أبابا'],
                  'alpha-2-code': 'ET',
                  'continent': 'إفريقيا',
                  'name': 'إثيوبيا',
                  'capital': 'أديس أبابا'},
                 {'timezones': ['أوروبا/هلسنكي'],
                  'alpha-2-code': 'FI',
                  'continent': 'أوروبا',
                  'name': 'فنلندا',
                  'capital': 'هلسنكي'},
                 {'timezones': ['المحيط_الهاديء/فيجي'],
                  'alpha-2-code': 'FJ',
                  'continent': 'أوقيانوسيا',
                  'name': 'فيجي',
                  'capital': 'سوفا'},
                 {'timezones': ['أوروبا/باريس'],
                  'alpha-2-code': 'FR',
                  'continent': 'أوروبا',
                  'name': 'فرنسا',
                  'capital': 'باريس'},
                 {'timezones': ['إفريقيا/ليبرفيل'],
                  'alpha-2-code': 'GA',
                  'continent': 'إفريقيا',
                  'name': 'الغابون',
                  'capital': 'ليبرفيل'},
                 {'timezones': ['آسيا/تبليسي'],
                  'alpha-2-code': 'GE',
                  'continent': 'آسيا',
                  'name': 'جورجيا',
                  'capital': 'تبليسي'},
                 {'timezones': ['إفريقيا/أكرا'],
                  'alpha-2-code': 'GH',
                  'continent': 'إفريقيا',
                  'name': 'غانا',
                  'capital': 'أكرا'},
                 {'timezones': ['إفريقيا/بانجول'],
                  'alpha-2-code': 'GM',
                  'continent': 'إفريقيا',
                  'name': 'غامبيا',
                  'capital': 'بانجول'},
                 {'timezones': ['إفريقيا/كوناكري'],
                  'alpha-2-code': 'GN',
                  'continent': 'إفريقيا',
                  'name': 'غينيا',
                  'capital': 'كوناكري'},
                 {'timezones': ['أوروبا/أثينا'],
                  'alpha-2-code': 'GR',
                  'continent': 'أوروبا',
                  'name': 'اليونان',
                  'capital': 'أثينا'},
                 {'timezones': ['أمريكا/غواتيمالا'],
                  'alpha-2-code': 'GT',
                  'continent': 'أمريكا الشمالية',
                  'name': 'غواتيمالا',
                  'capital': 'غواتيمالا سيتي'},
                 {'timezones': ['أمريكا/غواتيمالا'],
                  'alpha-2-code': 'GT',
                  'continent': 'أمريكا الشمالية',
                  'name': 'هايتي',
                  'capital': 'بورت أو برانس'},
                 {'timezones': ['إفريقيا/بيساو'],
                  'alpha-2-code': 'GW',
                  'continent': 'إفريقيا',
                  'name': 'غينيا بيساو',
                  'capital': 'بيساو'},
                 {'timezones': ['أمريكا/غيانا'],
                  'alpha-2-code': 'GY',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'غيانا',
                  'capital': 'جورج تاون'},
                 {'timezones': ['أمريكا/تيجوسيجالبا'],
                  'alpha-2-code': 'HN',
                  'continent': 'أمريكا الشمالية',
                  'name': 'هندوراس',
                  'capital': 'تيجوسيجالبا'},
                 {'timezones': ['أوروبا/بودابست'],
                  'alpha-2-code': 'HU',
                  'continent': 'أوروبا',
                  'name': 'هنغاريا',
                  'capital': 'بودابست'},
                 {'timezones': ['آسيا/جاكرتا',
                                'آسيا/بونتياناك',
                                'آسيا/ماكاسار',
                                'آسيا/جايابورا'],
                  'alpha-2-code': 'ID',
                  'continent': 'آسيا',
                  'name': 'إندونسيا',
                  'capital': 'جاكرتا'},
                 {'timezones': ['أوروبا/دبلن'],
                  'alpha-2-code': 'IE',
                  'continent': 'أوروبا',
                  'name': 'إيرلندا',
                  'capital': 'دبلن'},
                 {'timezones': ['آسيا/القدس'],
                  'alpha-2-code': 'IL',
                  'continent': 'آسيا',
                  'name': 'فلسطين',
                  'capital': 'القدس'},
                 {'timezones': ['آسيا/كالكتا'],
                  'alpha-2-code': 'IN',
                  'continent': 'آسيا',
                  'name': 'الهند',
                  'capital': 'نيو دلهي'},
                 {'timezones': ['آسيا/بغداد'],
                  'alpha-2-code': 'IQ',
                  'continent': 'آسيا',
                  'name': 'العراق',
                  'capital': 'بغداد'},
                 {'timezones': ['آسيا/طهران'],
                  'alpha-2-code': 'IR',
                  'continent': 'آسيا',
                  'name': 'إيران',
                  'capital': 'طهران'},
                 {'timezones': ['الأطلنطي/ريكيافيك'],
                  'alpha-2-code': 'IS',
                  'continent': 'أوروبا',
                  'name': 'آيسلندا',
                  'capital': 'ريكيافيك'},
                 {'timezones': ['أوروبا/روما'],
                  'alpha-2-code': 'IT',
                  'continent': 'أوروبا',
                  'name': 'إيطاليا',
                  'capital': 'روما'},
                 {'timezones': ['أمريكا/جامايكا'],
                  'alpha-2-code': 'JM',
                  'continent': 'أمريكا الشمالية',
                  'name': 'جامايكا',
                  'capital': 'كينغستون'},
                 {'timezones': ['آسيا/عمّان'],
                  'alpha-2-code': 'JO',
                  'continent': 'آسيا',
                  'name': 'الأردن',
                  'capital': 'عمّان'},
                 {'timezones': ['آسيا/طوكيو'],
                  'alpha-2-code': 'JP',
                  'continent': 'آسيا',
                  'name': 'اليابان',
                  'capital': 'طوكيو'},
                 {'timezones': ['إفريقيا/نيروبي'],
                  'alpha-2-code': 'KE',
                  'continent': 'إفريقيا',
                  'name': 'كينيا',
                  'capital': 'نيروبي'},
                 {'timezones': ['آسيا/بشكيك'],
                  'alpha-2-code': 'KG',
                  'continent': 'آسيا',
                  'name': 'قيرغيزستان',
                  'capital': 'بشكيك'},
                 {'timezones': ['المحيط_الهاديء/تاراوا',
                                'المحيط_الهاديء/إيديربيري',
                                'المحيط_الهاديء/كريتيماتي'],
                  'alpha-2-code': 'KI',
                  'continent': 'أوقيانوسيا',
                  'name': 'كيريباتي',
                  'capital': 'جنوب تاراوا'},
                 {'timezones': ['آسيا/بيونغ_يانغ'],
                  'alpha-2-code': 'KP',
                  'continent': 'آسيا',
                  'name': 'كوريا الشمالية',
                  'capital': 'بيونغ يانغ'},
                 {'timezones': ['آسيا/سيؤول'],
                  'alpha-2-code': 'KR',
                  'continent': 'آسيا',
                  'name': '؛كوريا الجنوبية',
                  'capital': 'سيؤول'},
                 {'timezones': ['آسيا/الكويت'],
                  'alpha-2-code': 'KW',
                  'continent': 'آسيا',
                  'name': 'الكويت',
                  'capital': 'الكويت'},
                 {'timezones': ['آسيا/بيروت'],
                  'alpha-2-code': 'LB',
                  'continent': 'آسيا',
                  'name': 'لبنان',
                  'capital': 'بيروت'},
                 {'timezones': ['أوروبا/فادوز'],
                  'alpha-2-code': 'LI',
                  'continent': 'أوروبا',
                  'name': 'ليختنشتاين',
                  'capital': 'فادوز'},
                 {'timezones': ['إفريقيا/مونروفيا'],
                  'alpha-2-code': 'LR',
                  'continent': 'إفريقيا',
                  'name': 'ليبيريا',
                  'capital': 'مونروفيا'},
                 {'timezones': ['إفريقيا/ماسيرو'],
                  'alpha-2-code': 'LS',
                  'continent': 'إفريقيا',
                  'name': 'ليسوتو',
                  'capital': 'ماسيرو'},
                 {'timezones': ['أوروبا/فيلنيوس'],
                  'alpha-2-code': 'LT',
                  'continent': 'أوروبا',
                  'name': 'ليتوانيا',
                  'capital': 'فيلنيوس'},
                 {'timezones': ['أوروبا/لوكسمبرغ'],
                  'alpha-2-code': 'LU',
                  'continent': 'أوروبا',
                  'name': 'لوكسمبرغ',
                  'capital': 'لوكسمبرغ سيتي'},
                 {'timezones': ['أوروبا/ربيغ'],
                  'alpha-2-code': 'LV',
                  'continent': 'أوروبا',
                  'name': 'لاتفيا',
                  'capital': 'ربيغ'},
                 {'timezones': ['إفريقيا/طرابلس'],
                  'alpha-2-code': 'LY',
                  'continent': 'إفريقيا',
                  'name': 'ليبيا',
                  'capital': 'طرابلس'},
                 {'timezones': ['الهندي/أنتاناناريفو'],
                  'alpha-2-code': 'MG',
                  'continent': 'إفريقيا',
                  'name': 'مدغشقر',
                  'capital': 'أنتاناناريفو'},
                 {'timezones': ['المحيط_الهاديء/ماجورو',
                                'المحيط_الهاديء/كواجلين_أتول'],
                  'alpha-2-code': 'MH',
                  'continent': 'أوقيانوسيا',
                  'name': 'جزر مارشال',
                  'capital': 'ماجورو'},
                 {'timezones': ['أوروبا/سكوبيه'],
                  'alpha-2-code': 'MK',
                  'continent': 'أوروبا',
                  'name': 'جمهورية مقدونيا',
                  'capital': 'سكوبيه'},
                 {'timezones': ['إفريقيا/باماكو'],
                  'alpha-2-code': 'ML',
                  'continent': 'إفريقيا',
                  'name': 'مالي',
                  'capital': 'باماكو'},
                 {'timezones': ['آسيا/رانغون'],
                  'alpha-2-code': 'MM',
                  'continent': 'آسيا',
                  'name': 'ميانمار',
                  'capital': 'نايبيداو'},
                 {'timezones': ['آسيا/أولان_باتور',
                                'آسيا/Hovd',
                                'آسيا/تشويبالسان'],
                  'alpha-2-code': 'MN',
                  'continent': 'آسيا',
                  'name': 'مانغوليا',
                  'capital': 'أولان باتور'},
                 {'timezones': ['إفريقيا/نواكشط'],
                  'alpha-2-code': 'MR',
                  'continent': 'إفريقيا',
                  'name': 'موريتانيا',
                  'capital': 'نواكشط'},
                 {'timezones': ['أوروبا/مالطا'],
                  'alpha-2-code': 'MT',
                  'continent': 'أوروبا',
                  'name': 'مالطا',
                  'capital': 'فاليتا'},
                 {'timezones': ['الهندي/موريشيوس'],
                  'alpha-2-code': 'MU',
                  'continent': 'إفريقيا',
                  'name': 'موريشيوس',
                  'capital': 'بور لويس'},
                 {'timezones': ['الهندي/جزر_المالديف'],
                  'alpha-2-code': 'MV',
                  'continent': 'آسيا',
                  'name': 'جمهورية المالديف',
                  'capital': 'ماليه'},
                 {'timezones': ['إفريقيا/بلانتاير'],
                  'alpha-2-code': 'MW',
                  'continent': 'إفريقيا',
                  'name': 'ملاوي',
                  'capital': 'ليلونغوي'},
                 {'timezones': ['أمريكا/ميكسيكو_سيتي',
                                'أمريكا/كانكون',
                                'أمريكا/ميرديا',
                                'أمريكا/مونتيري',
                                'أمريكا/مازاتلان',
                                'أمريكا/شيواوا',
                                'أمريكا/ارموسييو_سونورا',
                                'أمريكا/تيخوانا'],
                  'alpha-2-code': 'MX',
                  'continent': 'أمريكا الشمالية',
                  'name': 'المكسيك',
                  'capital': 'ميكسيكو سيتي§'},
                 {'timezones': ['آسيا/كوالا_لامبور',
                                'آسيا/Kuching'],
                  'alpha-2-code': 'MY',
                  'continent': 'آسيا',
                  'name': 'ماليزيا',
                  'capital': 'كوالا لامبور'},
                 {'timezones': ['إفريقيا/مابوتو'],
                  'alpha-2-code': 'MZ',
                  'continent': 'إفريقيا',
                  'name': 'موزمبيق',
                  'capital': 'مابوتو'},
                 {'timezones': ['إفريقيا/ويندهوك'],
                  'alpha-2-code': 'NA',
                  'continent': 'إفريقيا',
                  'name': 'ناميبيا',
                  'capital': 'ويندهوك'},
                 {'timezones': ['إفريقيا/نيامي'],
                  'alpha-2-code': 'NE',
                  'continent': 'إفريقيا',
                  'name': 'النيجر',
                  'capital': 'نيامي'},
                 {'timezones': ['إفريقيا/لاغوس'],
                  'alpha-2-code': 'NG',
                  'continent': 'إفريقيا',
                  'name': 'نيجيريا',
                  'capital': 'أبوجا'},
                 {'timezones': ['أمريكا/ماناغوا'],
                  'alpha-2-code': 'NI',
                  'continent': 'أمريكا الشمالية',
                  'name': 'نيكاراغوا',
                  'capital': 'ماناغوا'},
                 {'timezones': ['أوروبا/أمستردام'],
                  'alpha-2-code': 'NL',
                  'continent': 'أوروبا',
                  'name': 'هولندا',
                  'capital': 'أمستردام'},
                 {'timezones': ['أوروبا/أوسلو'],
                  'alpha-2-code': 'NO',
                  'continent': 'أوروبا',
                  'name': 'النرويج',
                  'capital': 'أوسلو'},
                 {'timezones': ['آسيا/كاتماندو'],
                  'alpha-2-code': 'NP',
                  'continent': 'آسيا',
                  'name': 'النيبال',
                  'capital': 'كاتماندو'},
                 {'timezones': ['المحيط_الهاديء/ناورو'],
                  'alpha-2-code': 'NR',
                  'continent': 'أوقيانوسيا',
                  'name': 'ناورو',
                  'capital': 'يارين'},
                 {'timezones': ['المحيط_الهاديء/أوكلاند',
                                'المحيط_الهاديء/تشاتهام'],
                  'alpha-2-code': 'NZ',
                  'continent': 'أوقيانوسيا',
                  'name': 'نيوزيلاندا',
                  'capital': 'ويلينغتون'},
                 {'timezones': ['آسيا/مسقط'],
                  'alpha-2-code': 'OM',
                  'continent': 'آسيا',
                  'name': 'عمان',
                  'capital': 'مسقط'},
                 {'timezones': ['أمريكا/بنما'],
                  'alpha-2-code': 'PA',
                  'continent': 'أمريكا الشمالية',
                  'name': 'بنما',
                  'capital': 'بنما'},
                 {'timezones': ['أمريكا/ليما'],
                  'alpha-2-code': 'PE',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'البيرو',
                  'capital': 'ليما'},
                 {'timezones': ['المحيط_الهاديء/بورت_مورسبي'],
                  'alpha-2-code': 'PG',
                  'continent': 'أوقيانوسيا',
                  'name': 'بابوا غينيا الجديدة',
                  'capital': 'بورت مورسبي'},
                 {'timezones': ['آسيا/مانيلا'],
                  'alpha-2-code': 'PH',
                  'continent': 'آسيا',
                  'name': 'الفيليبين',
                  'capital': 'مانيلا'},
                 {'timezones': ['آسيا/كاراتشي'],
                  'alpha-2-code': 'PK',
                  'continent': 'آسيا',
                  'name': 'باكستان',
                  'capital': 'إسلام أباد'},
                 {'timezones': ['أوروبا/وارسو'],
                  'alpha-2-code': 'PL',
                  'continent': 'أوروبا',
                  'name': 'بولندا',
                  'capital': 'وارسو'},
                 {'timezones': ['أوروبا/لشبونة',
                                'الأطلنطي/ماديرا',
                                'الأطلنطي/الأزور'],
                  'alpha-2-code': 'PT',
                  'continent': 'أوروبا',
                  'name': 'البرتغال',
                  'capital': 'لشبونة'},
                 {'timezones': ['المحيط_الهاديء/بالاو'],
                  'alpha-2-code': 'PW',
                  'continent': 'أوقيانوسيا',
                  'name': 'بالاو',
                  'capital': 'نجيرولمد'},
                 {'timezones': ['أمريكا/أسونسيون'],
                  'alpha-2-code': 'PY',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'بابرغوي',
                  'capital': 'أسونسيون'},
                 {'timezones': ['آسيا/قطر'],
                  'alpha-2-code': 'QA',
                  'continent': 'آسيا',
                  'name': 'قطر',
                  'capital': 'الدوحة'},
                 {'timezones': ['أوروبا/بوخارست'],
                  'alpha-2-code': 'RO',
                  'continent': 'أوروبا',
                  'name': 'رومانيا',
                  'capital': 'بوخارست'},
                 {'timezones': ['أوروبا/كالينينغراد',
                                'أوروبا/موسكو',
                                'أوروبا/Volgograd',
                                'أوروبا/سمارة',
                                'آسيا/يكاترينبورغ',
                                'آسيا/أومسك',
                                'آسيا/نوفوسيبيرسك',
                                'آسيا/كراسنوياسك',
                                'آسيا/إروتسك',
                                'آسيا/ياكوتسك',
                                'آسيا/فالديفوستوك',
                                'آسيا/ساخالن',
                                'آسيا/ماغادان',
                                'آسيا/كامشتكا',
                                'آسيا/أنادير'],
                  'alpha-2-code': 'RU',
                  'continent': 'أوروبا',
                  'name': 'روسيا',
                  'capital': 'موسكو'},
                 {'timezones': ['إفريقيا/كيغالي'],
                  'alpha-2-code': 'RW',
                  'continent': 'إفريقيا',
                  'name': 'رواندا',
                  'capital': 'كيغالي'},
                 {'timezones': ['آسيا/الرياض'],
                  'alpha-2-code': 'SA',
                  'continent': 'آسيا',
                  'name': 'المملكة العربية السعودية',
                  'capital': 'الرياض'},
                 {'timezones': ['المحيط_الهاديء/غوادالكانال'],
                  'alpha-2-code': 'SB',
                  'continent': 'أوقيانوسيا',
                  'name': 'جزر سولمون',
                  'capital': 'هونيارا'},
                 {'timezones': ['الهندي/ماهي'],
                  'alpha-2-code': 'SC',
                  'continent': 'إفريقيا',
                  'name': 'سيشل',
                  'capital': 'فيكتوريا'},
                 {'timezones': ['إفريقيا/الخرطوم'],
                  'alpha-2-code': 'SD',
                  'continent': 'إفريقيا',
                  'name': 'السودان',
                  'capital': 'الخرطوم'},
                 {'timezones': ['أوروبا/ستوكهولم'],
                  'alpha-2-code': 'SE',
                  'continent':'أوروبا',
                  'name': 'السويد',
                  'capital': 'ستوكهولم'},
                 {'timezones': ['آسيا/سنغافورة'],
                  'alpha-2-code': 'SG',
                  'continent': 'آسيا',
                  'name': 'سنغافورة',
                  'capital': 'سنغافورة'},
                 {'timezones': ['أوروبا/ليوبليانا'],
                  'alpha-2-code': 'SI',
                  'continent': 'أوروبا',
                  'name': 'سلوفانيا',
                  'capital': 'ليوبليانا'},
                 {'timezones': ['أوروبا/براتيسلافا'],
                  'alpha-2-code': 'SK',
                  'continent': 'أوروبا',
                  'name': 'سلوفاكيا',
                  'capital': 'براتيسلافا'},
                 {'timezones': ['إفريقيا/فريتاون'],
                  'alpha-2-code': 'SL',
                  'continent': 'إفريقيا',
                  'name': 'سيراليون',
                  'capital': 'فريتاون'},
                 {'timezones': ['أوروبا/سان_مارينو'],
                  'alpha-2-code': 'SM',
                  'continent': 'أوروبا',
                  'name': 'جمهورية سان مارينو',
                  'capital': 'سان مارينو'},
                 {'timezones': ['إفريقيا/داكار'],
                  'alpha-2-code': 'SN',
                  'continent': 'إفريقيا',
                  'name': 'السنغال',
                  'capital': 'داكار'},
                 {'timezones': ['إفريقيا/مقديشو'],
                  'alpha-2-code': 'SO',
                  'continent': 'إفريقيا',
                  'name': 'الصومال',
                  'capital': 'مقديشو'},
                 {'timezones': ['أمريكا/باراماريبو'],
                  'alpha-2-code': 'SR',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'Suriname',
                  'capital': 'باراماريبو'},
                 {'timezones': ['إفريقيا/ساو_تومي'],
                  'alpha-2-code': 'ST',
                  'continent': 'إفريقيا',
                  'name': ' ساو تومي وبرينسيب',
                  'capital': 'ساو تومي'},
                 {'timezones': ['آسيا/دممشق'],
                  'alpha-2-code': 'SY',
                  'continent': 'آسيا',
                  'name': 'سوريا',
                  'capital': 'دمشق'},
                 {'timezones': ['إفريقيا/لومي'],
                  'alpha-2-code': 'TG',
                  'continent': 'إفريقيا',
                  'name': 'توغو',
                  'capital': 'لومي'},
                 {'timezones': ['آسيا/بانغوك'],
                  'alpha-2-code': 'TH',
                  'continent': 'آسيا',
                  'name': 'تايلند',
                  'capital': 'بناغوك'},
                 {'timezones': ['آسيا/دوشنبه'],
                  'alpha-2-code': 'TJ',
                  'continent': 'آسيا',
                  'name': 'طاجكيستان',
                  'capital': 'دوشنبه'},
                 {'timezones': ['آسيا/عشق_آباد'],
                  'alpha-2-code': 'TM',
                  'continent': 'آسيا',
                  'name': 'تركمانستان',
                  'capital': 'عشق آباد'},
                 {'timezones': ['إفريقيا/تونس'],
                  'alpha-2-code': 'TN',
                  'continent': 'إفريقيا',
                  'name': 'تونس',
                  'capital': 'تونس'},
                 {'timezones': ['المحيط_الهاديء/تونغاتابو'],
                  'alpha-2-code': 'TO',
                  'continent': 'أوقيانوسيا',
                  'name': 'تونغا',
                  'capital': 'نوكو ألوفا'},
                 {'timezones': ['أوروبا/إسطنبول'],
                  'alpha-2-code': 'TR',
                  'continent': 'آسيا',
                  'name': 'تركيا',
                  'capital': 'أنقرة'},
                 {'timezones': ['أمريكا/بورت_أوف_سبين'],
                  'alpha-2-code': 'TT',
                  'continent': 'أمريكا الشمالية',
                  'name': 'ترينيداد وتوباغو',
                  'capital': 'بورت أوف سبين'},
                 {'timezones': ['المحيط_الهاديء/فونافوتي'],
                  'alpha-2-code': 'TV',
                  'continent': 'أوقيانوسيا',
                  'name': 'توفالو',
                  'capital': 'فونافوتي'},
                 {'timezones': ['إفريقيا/دار_السلام'],
                  'alpha-2-code': 'TZ',
                  'continent': 'إفريقيا',
                  'name': 'تانزانيا',
                  'capital': 'دودوما'},
                 {'timezones': ['أوروبا/كييف',
                                'أوروبا/أوجهورود',
                                'أوروبا/زاباروجيا',
                                'أوروبا/سيمفروبول'],
                  'alpha-2-code': 'UA',
                  'continent': 'أوروبا',
                  'name': 'أوكرانيا',
                  'capital': 'كييف'},
                 {'timezones': ['إفريقيا/كامبالا'],
                  'alpha-2-code': 'UG',
                  'continent': 'إفريقيا',
                  'name': 'أوغندا',
                  'capital': 'كامبالا'},
                 {'timezones': ['أمريكا/نيويورك',
                                'أمريكا/ديترويت',
                                'أمريكا/كنتاكي/لويسفيل',
                                'أمريكا/كنتاكي/مونتيسللو',
                                'أمريكا/إنديانا/إنديانابولس',
                                'أمريكا/إنديانا/مارنغو',
                                'أمريكا/إنديانا/نوكس',
                                'أمريكا/إنديانا/فيفاي',
                                'أمريكا/شيكاغو',
                                'أمريكا/إنديانا/فانسان',
                                'أمريكا/إنديانا/بيترزبيرغ',
                                'أمريكا/مينومني',
                                'أمريكا/نورث_داكوتا/سينتر',
                                'أمريكا/نورث_داكوتا/نيو_سالم',
                                'أمريكا/دنفر',
                                'أمريكا/بويسي',
                                'أمريكا/شيبروك',
                                'أمريكا/فينيكس',
                                'أمريكا/لوس_أنجيلوس',
                                'أمريكا/أنكوريج',
                                'أمريكا/جونو',
                                'أمريكا/ياكوتات',
                                'أمريكا/نوم',
                                'أمريكا/أداك',
                                'المحيط_الهاديء/هونولولو'],
                  'alpha-2-code': 'US',
                  'continent': 'أمريكا الشمالية',
                  'name': 'الولايات المتحدة الأمريكية',
                  'capital': 'واشنطن'},
                 {'timezones': ['أمريكا/مونتفيدو'],
                  'alpha-2-code': 'UY',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'أوروغواي',
                  'capital': 'مونتفيدو'},
                 {'timezones': ['آسيا/سمرقند',
                                'آسيا/طشقند'],
                  'alpha-2-code': 'UZ',
                  'continent': 'آسيا',
                  'name': 'أوزبكستان',
                  'capital': 'طشقند'},
                 {'timezones': ['أوروبا/الفاتيكان'],
                  'alpha-2-code': 'VA',
                  'continent': 'أوروبا',
                  'name': 'الفاتيكان',
                  'capital': 'الفاتيكان'},
                 {'timezones': ['أمريكا/كاركاس'],
                  'alpha-2-code': 'VE',
                  'continent': 'أمريكا الجنوبية',
                  'name': 'فنزويلا',
                  'capital': 'كاركاس'},
                 {'timezones': ['آسيا/سايغون'],
                  'alpha-2-code': 'VN',
                  'continent': 'آسيا',
                  'name': 'فيتنام',
                  'capital': 'هانوي'},
                 {'timezones': ['المحيط_الهاديء/أيفاتي'],
                  'alpha-2-code': 'VU',
                  'continent': 'أوقيانوسيا',
                  'name': 'فانواتو',
                  'capital': 'بورت فيلا'},
                 {'timezones': ['آسيا/عدن'],
                  'alpha-2-code': 'YE',
                  'continent': 'آسيا',
                  'name': 'اليمن',
                  'capital': "صنعاء"},
                 {'timezones': ['إفريقيا/لوساكا'],
                  'alpha-2-code': 'ZM',
                  'continent': 'إفريقيا',
                  'name': 'زامبيا',
                  'capital': 'لوساكا'},
                 {'timezones': ['إفريقيا/هراري'],
                  'alpha-2-code': 'ZW',
                  'continent': 'إفريقيا',
                  'name': 'زيمبابوي',
                  'capital': 'هراري'},
                 {'timezones': ['إفريقيا/الجزائر'],
                  'alpha-2-code': 'DZ',
                  'continent': 'إفريقيا',
                  'name': 'الجزائر',
                  'capital': 'الجزائر'},
                 {'timezones': ['أوروبا/سراييفو'],
                  'alpha-2-code': 'BA',
                  'continent': 'أوروبا',
                  'name': 'البوسنة والهرسك',
                  'capital': 'سراييفو'},
                 {'timezones': ['آسيا/بنوم_بنه'],
                  'alpha-2-code': 'KH',
                  'continent': 'آسيا',
                  'name': 'كمبوديا',
                  'capital': 'بنوم بنه'},
                 {'timezones': ['إفريقيا/بانغي'],
                  'alpha-2-code': 'CF',
                  'continent': 'إفريقيا',
                  'name': 'جمهورية أفريقيا الوسطى',
                  'capital': 'بانغي'},
                 {'timezones': ['إفريقيا/نجامينا'],
                  'alpha-2-code': 'TD',
                  'continent': 'إفريقيا',
                  'name': 'تشاد',
                  'capital': "نجامينا"},
                 {'timezones': ['الهندي/كومورو'],
                  'alpha-2-code': 'KM',
                  'continent': 'إفريقيا',
                  'name': 'جزر القمر',
                  'capital': 'موروني'},
                 {'timezones': ['أوروبا/زغرب'],
                  'alpha-2-code': 'HR',
                  'continent': 'أوروبا',
                  'name': 'كرواتيا',
                  'capital': 'زغرب'},
                 {'timezones': ['آسيا/ديلي'],
                  'alpha-2-code': 'TL',
                  'continent': 'آسيا',
                  'name': 'تيمور الشرقية',
                  'capital': 'ديلي'},
                 {'timezones': ['أمريكا/السلفادور'],
                  'alpha-2-code': 'SV',
                  'continent': 'أمريكا الشمالية',
                  'name': 'السلفادور',
                  'capital': 'سان سلفادور'},
                 {'timezones': ['إفريقيا/مالابو'],
                  'alpha-2-code': 'GQ',
                  'continent': 'إفريقيا',
                  'name': 'غينيا الاستوائية',
                  'capital': 'مالابو'},
                 {'timezones': ['أمريكا/غرينادا'],
                  'alpha-2-code': 'GD',
                  'continent': 'أمريكا الشمالية',
                  'name': 'غرينادا',
                  'capital': "سانت جورجز"},
                 {'timezones': ['آسيا/ألماتي',
                                'آسيا/كيزيلوردا',
                                'آسيا/أقتوبي',
                                'آسيا/أقتاو',
                                'آسيا/أورال'],
                  'alpha-2-code': 'KZ',
                  'continent': 'آسيا',
                  'name': 'كازاخستان',
                  'capital': 'أستانة'},
                 {'timezones': ['آسيا/فيينتيان'],
                  'alpha-2-code': 'LA',
                  'continent': 'آسيا',
                  'name': 'لاوس',
                  'capital': 'فيينتيان'},
                 {'timezones': ['المحيط_الهاديء/تشوك',
                                'المحيط_الهاديء/بونابي',
                                'المحيط_الهاديء/كورساي'],
                  'alpha-2-code': 'FM',
                  'continent': 'أوقيانوسيا',
                  'name': 'ولايات ميكرونيسيا المتحدة',
                  'capital': 'باليكير'},
                 {'timezones': ['أوروبا/كيشيناو'],
                  'alpha-2-code': 'MD',
                  'continent': 'أوروبا',
                  'name': 'مولدافيا',
                  'capital': 'كيشيناو'},
                 {'timezones': ['أوروبا/موناكو'],
                  'alpha-2-code': 'MC',
                  'continent': 'أوروبا',
                  'name': 'موناكو',
                  'capital': 'موناكو'},
                 {'timezones': ['أوروبا/بودغوريتسا'],
                  'alpha-2-code': 'ME',
                  'continent': 'أوروبا',
                  'name': 'الجبل الأسود',
                  'capital': 'بودغوريتسا'},
                 {'timezones': ['إفريقيا/الدار_البيضاء'],
                  'alpha-2-code': 'MA',
                  'continent': 'إفريقيا',
                  'name': 'المغرب',
                  'capital': 'الرباط'},
                 {'timezones': ['أمريكا/سانت_كيتس'],
                  'alpha-2-code': 'KN',
                  'continent': 'أمريكا الشمالية',
                  'name': 'سانت كيتس ونيفيس',
                  'capital': 'باستير'},
                 {'timezones': ['أمريكا/سانت_لوسيا'],
                  'alpha-2-code': 'LC',
                  'continent': 'أمريكا الشمالية',
                  'name': 'سانت لوسيا',
                  'capital': 'كاستريس'},
                 {'timezones': ['أمريكا/سينت_فينسينت'],
                  'alpha-2-code': 'VC',
                  'continent': 'أمريكا الشمالية',
                  'name': 'سانت فينسنت والغرينادين',
                  'capital': 'كينغستاون'},
                 {'timezones': ['المحيط_الهاديء/أبيا'],
                  'alpha-2-code': 'WS',
                  'continent': 'أوقيانوسيا',
                  'name': 'ساموا',
                  'capital': 'أبيا'},
                 {'timezones': ['أوروبا/بلغراد'],
                  'alpha-2-code': 'RS',
                  'continent': 'أوروبا',
                  'name': 'صربيا',
                  'capital': 'بلغراد'},
                 {'timezones': ['إفريقيا/جوهانسبرغ'],
                  'alpha-2-code': 'ZA',
                  'continent': 'إفريقيا',
                  'name': 'جنوب إفريقيا',
                  'capital': 'بريتوريا'},
                 {'timezones': ['أوروبا/مدريد',
                                'إفريقيا/سبتة',
                                'الأطلنطي/الكناري'],
                  'alpha-2-code': 'ES',
                  'continent': 'أوروبا',
                  'name': 'إسبانيا',
                  'capital': 'مدريد'},
                 {'timezones': ['آسيا/كولمبو'],
                  'alpha-2-code': 'LK',
                  'continent': 'آسيا',
                  'name': 'سريلانكا',
                  'capital': 'سري جاياواردنابورا كوتي'},
                 {'timezones': ['إفريقيا/مبابان'],
                  'alpha-2-code': 'SZ',
                  'continent': 'إفريقيا',
                  'name': 'سوازيلاند',
                  'capital': 'مبابان'},
                 {'timezones': ['أوروبا/زيورخ'],
                  'alpha-2-code': 'CH',
                  'continent': 'أوروبا',
                  'name': 'سويسرا',
                  'capital': 'برن'},
                 {'timezones': ['آسيا/دبي'],
                  'alpha-2-code': 'AE',
                  'continent': 'آسيا',
                  'name': 'الإمارات العربية المتحدة',
                  'capital': 'أبو ظبي'},
                 {'timezones': ['أوروبا/لندن'],
                  'alpha-2-code': 'GB',
                  'continent': 'أوروبا',
                  'name': 'المملكة المتحدة',
                  'capital': 'لندن'},
                 ]

    AM_PM = {
        'AM': 'ص',
        'PM': 'م',
    }

    def month_name(self):
        month = self.date('%m')
        return self.MONTH_NAMES[month]

    def am_pm(self):
        date = self.date('%p')
        return self.AM_PM[date]

    def day_of_week(self):
        day = self.date('%w')
        return self.DAY_NAMES[day]



# coding=utf-8

from .. import BaseProvider
from string import ascii_uppercase
import re

localized = True


class Provider(BaseProvider):
    license_formats = ()

    def license_plate(self):
        temp = re.sub(r'\?',
                      lambda x: self.random_element(ascii_uppercase),
                      self.random_element(self.license_formats))
        return self.numerify(temp)



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}} {{last_name}} {{company_suffix}}',
        '{{last_name}} & {{last_name}} {{company_suffix}}',
    )

    company_suffixes = (
        'AB', 'HB',
    )



# coding=utf-8

from __future__ import absolute_import, unicode_literals

import locale as pylocale
import logging
import sys

from importlib import import_module

from faker import Generator
from faker.config import AVAILABLE_LOCALES, DEFAULT_LOCALE, PROVIDERS
from faker.utils.loading import list_module

logger = logging.getLogger(__name__)

# identify if python is being run in interactive mode. If so, disable logging.
inREPL = bool(getattr(sys, 'ps1', False))
if inREPL:
    logger.setLevel(logging.CRITICAL)
else:
    logger.debug('Not in REPL -> leaving logger event level as is.')


class Factory(object):

    @classmethod
    def create(
            cls,
            locale=None,
            providers=None,
            generator=None,
            includes=None,
            **config):
        if includes is None:
            includes = []

        # fix locale to package name
        locale = locale.replace('-', '_') if locale else DEFAULT_LOCALE
        locale = pylocale.normalize(locale).split('.')[0]
        if locale not in AVAILABLE_LOCALES:
            msg = 'Invalid configuration for faker locale `{0}`'.format(locale)
            raise AttributeError(msg)

        config['locale'] = locale
        providers = providers or PROVIDERS

        providers += includes

        faker = generator or Generator(**config)

        for prov_name in providers:
            if prov_name == 'faker.providers':
                continue

            prov_cls, lang_found = cls._get_provider_class(prov_name, locale)
            provider = prov_cls(faker)
            provider.__provider__ = prov_name
            provider.__lang__ = lang_found
            faker.add_provider(provider)

        return faker

    @classmethod
    def _get_provider_class(cls, provider, locale=''):

        provider_class = cls._find_provider_class(provider, locale)

        if provider_class:
            return provider_class, locale

        if locale and locale != DEFAULT_LOCALE:
            # fallback to default locale
            provider_class = cls._find_provider_class(provider, DEFAULT_LOCALE)
            if provider_class:
                return provider_class, DEFAULT_LOCALE

        # fallback to no locale
        provider_class = cls._find_provider_class(provider)
        if provider_class:
            return provider_class, None

        msg = 'Unable to find provider `{0}` with locale `{1}`'.format(
            provider, locale)
        raise ValueError(msg)

    @classmethod
    def _find_provider_class(cls, provider_path, locale=None):

        provider_module = import_module(provider_path)

        if getattr(provider_module, 'localized', False):

            logger.debug('Looking for locale `{}` in provider `{}`.'.format(
                locale, provider_module.__name__))

            available_locales = list_module(provider_module)
            if not locale or locale not in available_locales:
                unavailable_locale = locale
                locale = getattr(
                    provider_module, 'default_locale', DEFAULT_LOCALE)
                logger.debug('Specified locale `{}` is not available for '
                             'provider `{}`. Locale reset to `{}` for this '
                             'provider.'.format(
                                 unavailable_locale, provider_module.__name__, locale),
                             )
            else:
                logger.debug('Provider `{}` has been localized to `{}`.'.format(
                    provider_module.__name__, locale))

            path = "{provider_path}.{locale}".format(
                provider_path=provider_path,
                locale=locale,
            )
            provider_module = import_module(path)

        else:

            logger.debug('Provider `{}` does not feature localization. '
                         'Specified locale `{}` is not utilized for this '
                         'provider.'.format(
                             provider_module.__name__, locale),
                         )

            if locale is not None:
                provider_module = import_module(provider_path)

        return provider_module.Provider



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}} {{last_name}} {{company_suffix}}',
        '{{last_name}}',
    )

    company_suffixes = (
        'AG', 'AG', 'AG', 'AG', 'AG & Co. KG', 'AG & Co. KGaA', 'AG & Co. OHG',
        'GbR', 'GbR', 'GmbH', 'GmbH', 'GmbH', 'GmbH', 'GmbH & Co. KG',
        'GmbH & Co. KG', 'GmbH & Co. KGaA', 'GmbH & Co. OHG', 'KG', 'KG', 'KG',
        'KGaA', 'OHG mbH', 'Stiftung & Co. KG', 'Stiftung & Co. KGaA', 'e.G.',
        'e.V.',
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as LoremProvider


class Provider(LoremProvider):
    common_words = (
        'άρα', 'ένα', 'ένας', 'έξι', 'έτσι', 'έχω', 'ήδη', 'ίδιο', 'αν', 'ανά',
        'από', 'ας', 'για', 'δε', 'δεν', 'δύο', 'εγώ', 'εδώ', 'εκτός', 'επί', 'θα',
        'κάτι', 'και', 'κι', 'μέχρι', 'μα', 'μας', 'με', 'μη', 'μην', 'μια', 'μιας',
        'μου', 'να', 'ναι', 'ο', 'οι', 'πάντα', 'πάντως', 'πιο', 'πλέον', 'ποια',
        'πολύ', 'που', 'πως', 'σαν', 'σας', 'σε', 'σου', 'στα', 'στη', 'στις',
        'στο', 'τα', 'τη', 'την', 'της', 'τι', 'τις', 'το', 'τον', 'του', 'τους',
        'των', 'ως', 'όσο', 'όταν', 'ότι', 'όχι',
    )

    word_list = common_words * 2 + (
        'άλγεβρα', 'άπειρα', 'άρα', 'άρθρων', 'άτομο', 'έγραψες', 'έλεγχος',
        'έξι', 'έρθει', 'έστειλε', 'έστελνε', 'έτοιμος', 'έτσι',
        'έχω', 'ήδη', 'ίδιο', 'αγοράζοντας', 'αθόρυβες', 'ακούσει', 'αλγόριθμου',
        'αναγκάζονται', 'ανακλύψεις', 'αναφέρονται', 'αναφορά',
        'ανεπιθύμητη', 'ανταγωνιστής', 'αντιλήφθηκαν', 'ανώδυνη', 'απίστευτα',
        'απαράδεκτη', 'απαραίτητο', 'απαρατήρητο', 'απλό', 'αποδείξεις',
        'αποθηκευτικού', 'αποκλειστικούς', 'απομόνωση', 'αποστηθίσει',
        'αποφάσισε', 'από', 'απόλαυσε', 'αρέσει', 'αρπάζεις', 'αρχεία',
        'ατόμου', 'αυτήν', 'αυτός', 'αφήσεις', 'βάζοντας', 'βαθμό',
        'βασανίζουν', 'βγήκε', 'βιαστικά', 'βιβλίο', 'βουτήξουν', 'βρίσκονται',
        'γέλασαν', 'γεγονός', 'γειτονιάς', 'γεύματος', 'για', 'γιαυτό',
        'γνωρίζουμε', 'γνωστή', 'γράψει', 'γραμμές', 'γραμμή', 'γραμμής',
        'γραφικά', 'δίνοντας', 'δε', 'δείξει', 'δεδομένων', 'δεν',
        'δημιουργήσεις', 'δημιουργείς', 'δημιουργια', 'διάβασε', 'διάσημα',
        'διαδίκτυο', 'διακοπή', 'διακοπής', 'διακόψουμε', 'διαπιστώνεις',
        'διασφαλίζεται', 'διαφήμιση', 'διαχειριστής', 'διευθυντές', 'διοικητικό',
        'διολισθήσεις', 'διορθώσει', 'διορθώσεις', 'δοκιμάσεις', 'δουλεύει',
        'δούλευε', 'δυστυχής', 'δυστυχώς', 'δωροδοκηθούν', 'δύο', 'είχαμε',
        'εγώ', 'εδώ', 'ειδικά', 'εικόνες', 'εκδόσεις', 'εκείνου', 'εκθέσεις',
        'εκτελέσει', 'εκτελέσεις', 'εκτελείται', 'εκτός', 'ελέγχου', 'εντολές',
        'εξακολουθεί', 'εξαρτάται', 'εξοργιστικά', 'επί', 'επενδυτής',
        'επεξεργασία', 'επιδιορθώσεις', 'επιδιόρθωση', 'επιστρέφουν',
        'επιχείριση', 'εργάστηκε', 'εργαζόμενοι', 'εργαζόμενων', 'εργαλείων',
        'εργασίας', 'εργοστασίου', 'ερωτήσεις', 'ερώτηση', 'εσωτερικών',
        'εταιρείες', 'ευκολότερο', 'εφαμοργής', 'εφαρμογή', 'εφαρμογής',
        'ζητήσεις', 'ημέρα', 'θέλεις', 'θέμα', 'θέματα', 'θυμάμαι',
        'ιδιαίτερα', 'κάνε', 'κάνεις', 'κάτι', 'και', 'καλύτερο', 'κανένας',
        'κανείς', 'κανόνα', 'καταλάθος', 'κειμένων', 'κι', 'κλπ', 'κοιτάζοντας',
        'κρατάει', 'κρατήσουν', 'κόλπα', 'κόψεις', 'κύκλο', 'κώδικάς', 'κώδικα',
        'λέει', 'λίγο', 'λαμβάνουν', 'λες', 'λετπά', 'λιγότερο', 'λοιπόν', 'μάθε',
        'μάλλον', 'μάτσο', 'μέγιστη', 'μέρος', 'μέσης', 'μέχρι', 'μαγικά',
        'μερικούς', 'μεταγλωτίσει', 'μεταγλωτιστής',
        'μεταφραστής', 'μετράει', 'μετρήσεις', 'μηχανής',
        'μπορούσες', 'μπουν', 'νέα', 'νέο', 'νέου', 'νέων', 'νιρβάνα', 'νόμιζες',
        'ξέχασε', 'ορίστε', 'πάντα', 'πάντως', 'πάρα', 'πάρεις', 'πήρε', 'παίξουν',
        'παίρνει', 'παίρνουν', 'πακέτων', 'παράγοντες', 'παράδειγμα',
        'παραγωγικής', 'παραδοτέου', 'παραδώσεις', 'παραπάνω', 'πεδία',
        'περίπου', 'περιβάλλον', 'περιβάλλοντος', 'περιεχόμενα', 'περιμένουν',
        'περισσότερες', 'περισσότερη', 'πες', 'πετάνε', 'πετάξαμε', 'πετούν',
        'πηγαίου', 'πιο', 'πλέον', 'ποια', 'πολύ', 'ποσοστό', 'που',
        'προβληματική', 'προγραμματιστές', 'προγραμματιστής', 'προκαλείς',
        'προκύπτουν', 'προσεκτικά', 'προσθέσει', 'προσλάμβανες', 'προσοχή',
        'προσπαθήσεις', 'προσπαθούν', 'προϊόντα', 'πρόσληψη', 'πρώτης', 'πρώτο',
        'πρώτοι', 'πόρτες', 'ροή', 'ρουτίνα', 'ρωτάει', 'ρωτήσει',
        'σίγουρος', 'σημαντικό', 'σημαντικός', 'σημεία',
        'σκεφτείς', 'σπίτι', 'στέλνοντάς', 'στήλες', 'σταματάς',
        'στραβά', 'συγγραφής', 'συγγραφείς',
        'συγκεντρωμένοι', 'συγχρόνως', 'συγχωνευτεί', 'συνάδελφος', 'συνέχεια',
        'συνεντεύξεις', 'συνεχώς', 'συνηθίζουν', 'σχεδιαστής', 'σωστά',
        'τέλειοι', 'τα', 'ταξινομεί', 'τεκμηριώνει', 'τελειώσει', 'τεσσαρών',
        'τοπικές', 'τρέξει', 'τρόπο', 'τρόποι', 'τύπου', 'τύπους', 'υπηρεσία',
        'υποψήφιο', 'υψηλότερη', 'υόρκη', 'φίλος', 'φαινόμενο', 'φακέλους',
        'φράση', 'χάος', 'χαμηλός', 'χαρακτηριστικό', 'χαρακτηριστικών',
        'χαρτιού', 'χειρότερα', 'χρειάζονται', 'χρησιμοποίησέ',
        'χρησιμοποιούνταν', 'χρησιμοποιούσες', 'χρησιμοποιώντας',
        'χρονοδιαγράμματα', 'χρονοδιαγράμματος', 'χρόνου', 'χώρου', 'ωραίο',
        'ύψος', 'ώρα',
    )



# coding=utf-8

from __future__ import unicode_literals
from collections import OrderedDict
from .. import Provider as ColorProvider


class Provider(ColorProvider):

    all_colors = OrderedDict((
        ("Ալիսի կապույտ", "#F0F8FF"),
        ("Անանուխի կրեմ", "#F5FFFA"),
        ("Անտառային կանաչ", "#228B22"),
        ("Արծաթագույն", "#C0C0C0"),
        ("Արքայական կապույտ", "#4169E1"),
        ("Բաց դեղին", "#FFFFE0"),
        ("Բաց դեղնաոսկեգույն", "#FAFAD2"),
        ("Բաց երկնագույն", "#87CEFA"),
        ("Բաց ծովային կանաչ", "#20B2AA"),
        ("Բաց կաթնագույն", "#FFFFF0"),
        ("Բաց կանաչ", "#90EE90"),
        ("Բաց կապույտ", "#ADD8E6"),
        ("Բաց կապտականաչ", "#E0FFFF"),
        ("Բաց կորալ", "#F08080"),
        ("Բաց մանուշակագույն", "#EE82EE"),
        ("Բաց մոխրագույն թերթաքար", "#778899"),
        ("Բաց մոխրագույն", "#D3D3D3"),
        ("Բաց նշագույն", "#FFEBCD"),
        ("Բաց պողպատե կապույտ", "#B0C4DE"),
        ("Բաց սաղմոնագույն", "#FFA07A"),
        ("Բաց վարդագույն", "#FFB6C1"),
        ("Բեժ", "#F5F5DC"),
        ("Բոսորագույն", "#DC143C"),
        ("Գարնանային կանաչ", "#00FF7F"),
        ("Գեյնսբորրո", "#DCDCDC"),
        ("Գունատ կանաչ", "#98FB98"),
        ("Գունատ կարմիր մանուշակագույն", "#DB7093"),
        ("Գունատ ոսկեգույն", "#EEE8AA"),
        ("Գունատ փիրուզագույն", "#AFEEEE"),
        ("Գրասենյակային կանաչ", "#008000"),
        ("Դարչնագույն ավազ", "#F4A460"),
        ("Դարչնագույն", "#964b00"),
        ("Դեղին", "#FFFF00"),
        ("Դեղձի կրեմ", "#FFDAB9"),
        ("Դեղնականաչ", "#9ACD3"),
        ("Դոդջերս կապույտ", "#1E90FF"),
        ("Եգիպտացորենի մազիկներ", "#FFF8DC"),
        ("Երկնագույն մառախուղ", "#F0FFFF"),
        ("Երկնագույն", "#87CEEB"),
        ("Զինվորական կանաչ", "#6B8E23"),
        ("Թամբի դարչնագույն", "#8B4513"),
        ("Թեժ վարդագույն", "#FF69B4"),
        ("Թուխ", "#D2B48C"),
        ("Ինդիգո", "#4B0082"),
        ("Լայմի կանաչ", "#32CD32"),
        ("Լավանդ", "#E6E6FA"),
        ("Լոլիկ", "#FF6347"),
        ("Խակի", "#F0E68C"),
        ("Խոլորձագույն", "#DA70D6"),
        ("Ծխագույն", "#F5F5F5"),
        ("Ծովախեցի", "#FFF5EE"),
        ("Ծովակնագույն", "#7FFFD4"),
        ("Ծովային կանաչ", "#2E8B57"),
        ("Կադետների կապույտ", "#5F9EA0"),
        ("Կաթնագույն", "#FFFAF0"),
        ("Կակաոյի դարչնագույն", "#D2691E"),
        ("Կանաչ", "#00FF00"),
        ("Կանաչադեղին", "#ADFF2F"),
        ("Կապույտ թերթաքար", "#6A5ACD"),
        ("Կապույտ մանուշակագույն", "#8A2BE2"),
        ("Կապույտ փոշի", "#B0E0E6"),
        ("Կապույտ", "#0000FF"),
        ("Կապտականաչ", "#00FFFF"),
        ("Կարմիր դարչնագույն", "#A52A2A"),
        ("Կարմիր լավանդ", "#FFF0F5"),
        ("Կարմիր մանուշակագույն", "#C71585"),
        ("Կարմիր", "#FF0000"),
        ("Կեսգիշերային կապույտ", "#191970"),
        ("Կիտրոնի շիֆոն", "#FFFACD"),
        ("Կորալ", "#FF7F50"),
        ("Հարած պապայա", "#FFEFD5"),
        ("Հին ժանյակ", "#FDF5E6"),
        ("Հնաոճ սպիտակ", "#FAEBD7"),
        ("Հնդկական կարմիր", "#CD5C5C"),
        ("Հրակայուն աղյուս", "#B22222"),
        ("Ձիթապտղի գույն", "#808000"),
        ("Ձյունաճերմակ", "#FFFAFA"),
        ("Մանուշակագույն", "#800080"),
        ("Մեղրացող սեխ", "#F0FFF0"),
        ("Միջին գարնանային կանաչ", "#00FA9A"),
        ("Միջին խոլորձագույն", "#BA55D3"),
        ("Միջին ծովակնագույն", "#66CDAA"),
        ("Միջին ծովային կանաչ", "#3CB371"),
        ("Միջին կապույտ թերթաքար", "#7B68EE"),
        ("Միջին կապույտ", "#0000CD"),
        ("Միջին կապտականաչ", "#9370DB"),
        ("Միջին փիրուզագույն", "#48D1CC"),
        ("Մոխրագույն թերթաքար", "#708090"),
        ("Մոխրագույն", "#808080"),
        ("Մոկասին", "#FFE4B5"),
        ("Մուգ երկնագույն", "#00BFFF"),
        ("Մուգ խակի", "#BDB76B"),
        ("Մուգ խոլորձագույն", "#9932CC"),
        ("Մուգ ծովային կանաչ", "#8FBC8F"),
        ("Մուգ կանաչ", "#006400"),
        ("Մուգ կապույտ թերթաքար", "#483D8B"),
        ("Մուգ կապույտ", "#00008B"),
        ("Մուգ կապտականաչ", "#008080"),
        ("Մուգ կարմիր", "#8B0000"),
        ("Մուգ ձիթապտղի կանաչ", "#556B2F"),
        ("Մուգ մանուշակագույն", "#9400D3"),
        ("Մուգ մոխրագույն թերթաքար", "#2F4F4F"),
        ("Մուգ մոխրագույն", "#696969"),
        ("Մուգ մոխրագույն", "#A9A9A9"),
        ("Մուգ նարնջագույն", "#FF8C00"),
        ("Մուգ ոսկեգույն", "#B8860B"),
        ("Մուգ սաղմոնագույն", "#E9967A"),
        ("Մուգ վառ մանուշակագույն", "#8B008B"),
        ("Մուգ վարդագույն", "#FF1493"),
        ("Մուգ փիրուզագույն", "#00CED1"),
        ("Նավահո սպիտակ", "#FFDEAD"),
        ("Նավատորմի կապույտ", "#000080"),
        ("Նարնջագույն կարմիր", "#FF4500"),
        ("Նարնջագույն", "#FFA500"),
        ("Նշագույն", "#FFE4C4"),
        ("Շագանակագույն", "#800000"),
        ("Շարտրուզ", "#7FFF00"),
        ("Ոսկեգույն ձող", "#DAA520"),
        ("Ոսկեգույն", "#FFD700"),
        ("Պերու", "#CD853F"),
        ("Պողպատե կապույտ", "#4682B4"),
        ("Սալոր", "#DDA0DD"),
        ("Սաղմոնագույն", "#FA8072"),
        ("Սիենա", "#A0522D"),
        ("Սիզամարգի կանաչ", "#7CFC00"),
        ("Սպիտակ ստվեր", "#F8F8FF"),
        ("Սպիտակ", "#FFFFFF"),
        ("Սև", "#000000"),
        ("Վառ մանուշակագույն", "#FF00FF"),
        ("Վարդագույն", "#FFC0CB"),
        ("Վարդագույն", "#FFE4E1"),
        ("Վարդադարչնագույն", "#BC8F8F"),
        ("Վուշ", "#FAF0E6"),
        ("Տատասկ", "#D8BFD8"),
        ("Տերեփուկի կապույտ", "#6495ED"),
        ("Ցորենագույն", "#F5DEB3"),
        ("Փիրուզագույն", "#40E0D0"),
        ("Փխրուն փայտ", "#DEB887"),
    ))

    safe_colors = (
        'սև', 'շագանակագույն', 'կանաչ', 'նավատորմի կապույտ', 'ձիթապտղի գույն',
        'մանուշակագույն', 'մուգ կապտականաչ', 'լայմ', 'կապույտ', 'արծաթագույն',
        'մոխրագույն', 'դեղին', 'վառ մանուշակագույն', 'կապտականաչ', 'սպիտակ',
    )



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    # from
    # https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Poland
    license_formats = (
        '?? #####',
        '?? ####?',
        '?? ###??',
        '?? #?###',
        '?? #??##',
        '??? ?###',
        '??? ##??',
        '??? #?##',
        '??? ##?#',
        '??? #??#',
        '??? ??##',
        '??? #####',
        '??? ####?',
        '??? ###??',
    )

    def license_plate_regex_formats(self):
        return [plate.replace('?', '[A-Z]').replace('#', '[0-9]') for plate in self.license_formats]



# coding=utf-8

from functools import wraps

from faker.utils import text


def slugify(fn):
    @wraps(fn)
    def wrapper(*args, **kwargs):
        return text.slugify(fn(*args, **kwargs))
    return wrapper


def slugify_domain(fn):
    @wraps(fn)
    def wrapper(*args, **kwargs):
        return text.slugify(fn(*args, **kwargs), allow_dots=True)
    return wrapper


def slugify_unicode(fn):
    @wraps(fn)
    def wrapper(*args, **kwargs):
        return text.slugify(fn(*args, **kwargs), allow_unicode=True)
    return wrapper


def lowercase(fn):
    @wraps(fn)
    def wrapper(*args, **kwargs):
        return fn(*args, **kwargs).lower()
    return wrapper



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as GeoProvider


class Provider(GeoProvider):

    nationalities = (
        "Afegã", "Albanesa", "Arménia", "Angolana", "Argentina", "Austríaca", "Australiana", "Azerbaijã", "Belga",
        "Bulgara", "Boliviana", "Brasileira", "Bielorussa", "Canadiana", "Congolesa (República Democrática do Congo)",
        "Congolesa (República do Congo)", "Suíça", "Marfinense", "Chilena", "Chinesa", "Colombiana", "Costa-Riquenha",
        "Cubana", "Cabo-verdiana", "Cipriota", "Checa", "Alemã", "Dinamarquesa", "Dominicana", "Argelina",
        "Equatoriana", "Estónia", "Egípcia", "Espanhola", "Etíope", "Finlândesa", "Francesa", "Grega",
        "Guineense (Bissau)", "Croata", "Húngara", "Indonésia", "Irlandesa", "Israelita", "Indiana", "Iraquiana",
        "Iraniana", "Islandesa", "Italiana", "Jamaicana", "Japonesa", "Queniana", "Coreana", "Libanesa", "Lituana",
        "Luxemburguesa", "Letã", "Marroquina", "Moldava", "Birmanesa", "Maltesa", "Mexicana", "Moçambicana",
        "Nigeriana", "Holandesa", "Norueguesa", "Nepalesa", "Neozelandesa", "Peruana", "Filipina", "Paquistanesa",
        "Polaca", "Portuguesa", "Paraguaia", "Romena", "Russa", "Ruandesa", "Sudanesa", "Sueca", "Eslovena", "Eslovaca",
        "Senegalesa", "Somali", "Santomense", "Salvadorenha", "Tailandesa", "Tunisina", "Turca", "Ucraniana",
        "Britânica", "Americana", "Uruguaia", "Venezuelana", "Vietnamita", "Sul-Africana", "Sérvia", "Andorrenha",
        "Bósnia", "Camaronesa", "Georgiana", "Ganesa", "Gambiana", "Hondurenha", "Haitiana", "Cazaque", "Libanesa ",
        "Monegasca", "Maliana", "Mongol", "Mauritana", "Malaia", "Panamiana", "Saudita", "Singapurense", "Togolesa",
    )

    def nationality(self):
        """
        :example 'Portuguesa'
        """
        return self.random_element(self.nationalities)



# -*- encoding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):

    # List of Countries https://www.un.org/es/members/
    countries = (
        'Afganistán', 'Albania', 'Alemania', 'Andorra', 'Angola',
        'Antigua y Barbuda', 'Arabia Saudita', 'Argelia', 'Argentina',
        'Armenia', 'Australia', 'Austria', 'Azerbaiyán', 'Bahamas', 'Bahrein',
        'Bangladesh', 'Barbados', 'Belarús', 'Bélgica', 'Belice', 'Benin',
        'Bhután', 'Bolivia', 'Bosnia y Herzegovina', 'Botswana', 'Brasil',
        'Brunei Darussalam', 'Bulgaria', 'Burkina Faso', 'Burundi',
        'Cabo Verde', 'Camboya', 'Camerún', 'Canadá', 'Chad', 'Chile', 'China',
        'Chipre', 'Colombia', 'Comoras', 'Congo', 'Costa Rica',
        'Côte d\'Ivoire', 'Croacia', 'Cuba', 'Dinamarca', 'Djibouti',
        'Dominicana', 'Ecuador', 'Egipto', 'El Salvador',
        'Emiratos Árabes Unidos', 'Eritrea', 'Eslovaquia', 'Eslovenia',
        'España', 'Estados Unidos de América', 'Estonia', 'Etiopía',
        'ex República Yugoslava de Macedonia', 'Federación de Rusia', 'Fiji',
        'Filipinas', 'Finlandia', 'Francia', 'Gabón', 'Gambia', 'Georgia',
        'Ghana', 'Granada', 'Grecia', 'Guatemala', 'Guinea', 'Guinea Bissau',
        'Guinea Ecuatorial', 'Guyana', 'Haití', 'Honduras', 'Hungría', 'India',
        'Indonesia', 'Irán', 'Iraq', 'Irlanda', 'Islandia', 'Islas Marshall',
        'Islas Salomón', 'Israel', 'Italia', 'Jamaica', 'Japón', 'Jordania',
        'Kazajstán', 'Kenya', 'Kirguistán', 'Kiribati', 'Kuwait', 'Lesotho',
        'Letonia', 'Líbano', 'Liberia', 'Libia', 'Liechtenstein', 'Lituania',
        'Luxemburgo', 'Madagascar', 'Malasia', 'Malawi', 'Maldivas', 'Mali',
        'Malta', 'Marruecos', 'Mauricio', 'Mauritania', 'México', 'Micronesia',
        'Mónaco', 'Mongolia', 'Montenegro', 'Mozambique', 'Myanmar', 'Namibia',
        'Nauru', 'Nicaragua', 'Niger', 'Nigeria', 'Noruega', 'Nueva Zelandia',
        'Omán', 'Países Bajos', 'Pakistán', 'Palau', 'Panamá',
        'Papua Nueva Guinea', 'Paraguay', 'Perú', 'Polonia', 'Portugal',
        'Qatar', 'Reino Unido de Gran Bretaña e Irlanda del Norte',
        'República Árabe Siria', 'República Centroafricana', 'República Checa',
        'República de Corea', 'República de Moldova',
        'República Democrática del Congo', 'República Democrática Popular Lao',
        'República Dominicana', 'República Federal Democrática de Nepal',
        'República Popular Democrática de Corea', 'República Unida de Tanzanía',
        'Rumania', 'Rwanda', 'Saint Kitts y Nevis', 'Samoa', 'San Marino',
        'Santa Lucía', 'Santo Tomé y Príncipe', 'San Vicente y las Granadinas',
        'Senegal', 'Serbia', 'Seychelles', 'Sierra Leona', 'Singapur',
        'Somalia', 'Sri Lanka', 'Sudáfrica', 'Sudán', 'Sudán del Sur', 'Suecia',
        'Suiza', 'Suriname', 'Swazilandia', 'Tailandia', 'Tayikistán',
        'Timor-Leste', 'Togo', 'Tonga', 'Trinidad y Tabago', 'Túnez',
        'Turkmenistán', 'Turquía', 'Tuvalu', 'Ucrania', 'Uganda', 'Uruguay',
        'Uzbekistán', 'Vanuatu', 'Venezuela', 'Vietman', 'Yemen', 'Zambia',
        'Zimbabwe',
    )



# coding: utf-8
from __future__ import unicode_literals

from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    def day_of_week(self):
        day = self.date('%w')
        DAY_NAMES = {
            "0": "Воскресенье",
            "1": "Понедельник",
            "2": "Вторник",
            "3": "Среда",
            "4": "Четверг",
            "5": "Пятница",
            "6": "Суббота",
        }
        return DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        MONTH_NAMES = {
            "01": "Январь",
            "02": "Февраль",
            "03": "Март",
            "04": "Апрель",
            "05": "Май",
            "06": "Июнь",
            "07": "Июль",
            "08": "Август",
            "09": "Сентябрь",
            "10": "Октябрь",
            "11": "Ноябрь",
            "12": "Декабрь",
        }
        return MONTH_NAMES[month]



# coding=utf-8
from __future__ import unicode_literals

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_suffixes = ['ул.']
    city_formats = ('{{city_prefix}} {{city_name}}', )
    street_name_formats = ('{{street_suffix}} {{street_title}}', )
    street_address_formats = ('{{street_name}}, д. {{building_number}}', )
    address_formats = ('{{city}}, {{street_address}}, {{postcode}}', )
    postcode_formats = ('######', )

    city_prefixes = (
        'г.', 'п.', 'к.', 'с.', 'д.', 'клх', 'ст.',
    )

    street_titles = (
        'Советская', 'Молодежная', 'Центральная', 'Школьная', 'Новая',
        'Садовая', 'Лесная', 'Набережная', 'Ленина', 'Мира', 'Октябрьская',
        'Зеленая', 'Комсомольская', 'Заречная', 'Первомайская', 'Гагарина',
        'Полевая', 'Луговая', 'Пионерская', 'Кирова', 'Юбилейная', 'Северная',
        'Пролетарская', 'Степная', 'Пушкина', 'Калинина', 'Южная', 'Колхозная',
        'Рабочая', 'Солнечная', 'Железнодорожная', 'Восточная', 'Заводская',
        'Чапаева', 'Нагорная', 'Строителей', 'Береговая', 'Победы', 'Горького',
        'Кооперативная', 'Красноармейская', 'Совхозная', 'Речная',
        'Спортивная', 'Озерная', 'Строительная', 'Парковая', 'Чкалова',
        'Мичурина', 'Подгорная', 'Дружбы', 'Почтовая', 'Партизанская',
        'Вокзальная', 'Лермонтова', 'Свободы', 'Дорожная', 'Дачная',
        'Маяковского', 'Западная', 'Фрунзе', 'Дзержинского', 'Московская',
        'Свердлова', 'Некрасова', 'Гоголя', 'Красная', 'Трудовая', 'Шоссейная',
        'Чехова', 'Коммунистическая', 'Труда', 'Комарова', 'Матросова',
        'Островского', 'Сосновая', 'Клубная', 'Куйбышева', 'Крупской',
        'Березовая', 'Карла Маркса', '8 Марта', 'Больничная',
        'Интернациональная', 'Суворова', 'Цветочная', 'Трактовая',
        'Ломоносова', 'Горная', 'Космонавтов', 'Энергетиков', 'Шевченко',
        'Весенняя', 'Механизаторов', 'Коммунальная', '40 лет Победы',
        'Майская', 'Энгельса', 'Привокзальная', 'Таежная', 'Транспортная',
        'Овражная', 'Светлая', '1 Мая', 'Вишневая', 'Чернышевского',
        'Урицкого', 'Ключевая', 'Ворошилова', 'Тургенева', 'Толстого',
        'Песчаная', 'Ленинградская', 'Профсоюзная', 'Буденного',
        'Орджоникидзе', 'Герцена', 'Верхняя', 'Ленинская', 'Кирпичная',
        'Мостовая', 'Щорса', 'Станционная', 'Луначарского', 'Энтузиастов',
        'Титова', 'Лазо', '50 лет Октября', 'Уральская', 'Линейная',
        'Пугачева', 'Володарского', 'Кутузова', 'Фабричная', 'Чайковского',
        'Магистральная', 'Сибирская', 'Крестьянская', 'Мелиораторов',
        'Российская', 'Новоселов', 'Тихая', 'Широкая', 'Нижняя', 'Белинского',
        'Тельмана', 'Тимирязева', 'Котовского', 'Народная', '60 лет Октября',
        'Промышленная', 'Кольцевая', 'Есенина', 'К.Маркса', 'Дальняя',
        '40 лет Октября', 'Крылова', 'Декабристов', 'Базарная', 'Целинная',
        'Родниковая', '70 лет Октября', 'Фурманова', 'Революционная',
        'Социалистическая', 'Звездная', 'Студенческая', 'Гайдара', 'Мирная',
        'Терешковой', 'Кубанская', 'Гаражная', 'Фестивальная', 'Гражданская',
        'Песочная', 'Сиреневая', 'Ватутина', 'Сельская', 'Кузнечная',
        'Пушкинская', 'Крайняя', 'Коммунаров', 'Гвардейская', 'Веселая',
        'Загородная', 'Олимпийская', 'Гастелло', 'Жданова', 'Радищева',
        'Нефтяников', 'Осипенко', 'Приозерная', 'Рябиновая', 'Заозерная',
        'Нахимова', 'Боровая', 'Жукова', 'Павлова', 'Степана Разина',
        'Урожайная', 'Попова', 'Торговая', 'Жуковского', 'Королева', 'Донская',
        'Пограничная', 'Огородная', 'Пригородная', 'Грибоедова', 'Стадионная',
        'Менделеева', 'Достоевского', 'Репина', 'Виноградная', 'Циолковского',
        'Воровского', 'Киевская', 'Максима Горького', 'Революции',
        'Индустриальная', 'Красногвардейская', 'Волжская', 'Кошевого',
        'Пархоменко', 'Свободная', 'Кедровая', 'Подлесная', 'Полярная',
        'Раздольная', 'Карьерная', 'Мельничная', 'Серова', 'Украинская',
        'Шахтерская', 'Запрудная', 'Элеваторная', 'Театральная', 'Добролюбова',
        'Геологическая', '50 лет Победы', 'Болотная', 'Красина', 'Коминтерна',
        'Придорожная', '30 лет Победы', 'Кленовая', 'Разина', 'Черняховского',
        'Казачья', 'Ветеранов', 'Малая', 'Пирогова', 'Льва Толстого',
        'Геологов', 'Тукая', 'Морская', 'Волгоградская', 'Димитрова',
        'Средняя', 'М.Горького', 'Безымянная', 'Краснофлотская', 'Братская',
        'Розы Люксембург', 'Тенистая', 'Учительская', 'Маркса', 'Кавказская',
        'Ушакова', 'Короткая', 'Деповская', 'Амурская', 'Сенная', 'Поселковая',
        '9 Мая', 'Юности', 'Короленко', 'Прудовая', 'Шолохова', 'Депутатская',
        'Авиационная', '50 лет ВЛКСМ', 'Черемушки', 'Кольцова', 'Плеханова',
        'Аэродромная', 'Большая', 'Приморская', 'Алтайская', 'Макаренко',
        'Глинки', 'Специалистов', 'Халтурина', 'Морозова', 'Тополиная',
        'Ростовская', 'Тракторная', 'Коммуны', 'Мелиоративная', 'Ольховая',
        'Славянская', 'Красных Партизан', 'Зои Космодемьянской', 'Карбышева',
        'Баумана', 'Радужная', 'Марта 8', 'Правды', 'Маркса Карла',
        'Краснодарская', 'Фадеева', '60 лет СССР', 'Стахановская',
        'Ярославская', 'Челюскинцев', 'Коллективная', 'Ангарская',
        'Олега Кошевого', 'Новостройка', 'Шмидта', 'Кузнецова', 'Локомотивная',
        'Войкова', 'Панфилова', 'Ягодная', 'Смоленская', 'Тепличная',
        'Карла Либкнехта', 'Парижской Коммуны', 'Водопроводная',
        'Республиканская', 'Автомобилистов', 'Космодемьянской', 'Осенняя',
        'Байкальская', 'Седова', 'Саратовская', 'Казанская', 'Блюхера',
        'Воронежская', 'Демьяна Бедного', 'Брянская', 'Производственная',
        'Спартака', 'Техническая', 'Енисейская', 'Николаева', 'Бабушкина',
        'Севастопольская', 'Окружная', 'Октября', 'Щетинкина', 'Орловская',
        'Хуторская', 'Тупиковая', 'Каштановая', 'Омская', 'Гончарова',
        'Привольная', 'Щербакова', 'Курортная', 'Ивановская', 'Выгонная',
        'Крымская', 'Путейская', 'Азина', 'Проезжая', 'Сурикова',
        'Краснознаменная', 'Одесская', '9 Января', 'Подстанция',
        'Логовая', 'Высокая', 'Ясная', 'Портовая', 'Снежная', 'Санаторная',
        'Союзная', 'Волкова', 'Ульяновская', 'Никитина', 'Сахалинская',
        'Горняцкая', 'Рылеева', 'Прибрежная', 'Химиков', 'Рыбацкая',
        'Полтавская', 'Тамбовская', 'Красноярская', 'Новосельская',
        'Проточная', 'Черноморская', 'Курчатова', 'Минская', 'Микрорайон',
        'Главная', 'Докучаева', 'Вольная', 'Просвещения', 'Смирнова',
        'Хвойная', 'Космическая', 'Моховая', 'Макарова', 'Курская',
        'Курганная', 'Угловая', 'Камская', 'Инженерная', 'Лесозаводская',
        'Астраханская', 'Иванова', 'Л.Толстого', 'Гафури', 'Высоцкого',
        'Белорусская', 'Бажова', 'Кочубея', 'Заовражная', 'Азовская',
        'Ручейная', 'Леонова', 'Волочаевская', 'Надежды', 'Ставропольская',
        'Металлистов', 'Вавилова', 'Слободская', 'Ульянова', 'Тульская',
        'Харьковская', 'Петровская', 'Павлика Морозова', 'Владимирская',
        'Семашко', 'Высоковольтная', 'Шаумяна', 'Чайкиной', 'Лазурная',
        'Ермака', 'Дорожников', 'Покровская', 'Новгородская', 'Ленская',
        'Советской Армии', 'Сплавная', 'Ударная', 'Калужская', 'Монтажников',
        'Прудная', 'Шишкина', 'Краснопартизанская', 'Ореховая', 'Таманская',
        'Иркутская', 'Металлургов', 'Отрадная', 'Беляева', 'Большевистская',
        'Троицкая', 'Лесхозная', 'Дружба', 'Васильковая', 'Серафимовича',
        'Ильича', 'Мусы Джалиля', 'Механическая', 'Невского', 'Путевая',
        'Клары Цеткин', 'Кузнецкая', 'Физкультурная', 'Леваневского',
        'Водников', 'Вахитова', 'Станиславского', 'Черемуховая', 'Советов',
        'Флотская', 'Угольная', 'Восьмого Марта', 'Пожарского', 'Папанина',
        'Просторная', 'Поперечная', 'Городская', 'Победа', '8-е Марта',
        'Абрикосовая', 'Бульварная', 'Прохладная', 'Томская', 'Энергетическая',
        'Литейная', 'Медицинская', 'Заливная', 'Журавлева', 'Бригадная',
        'Культуры', 'Мая 1', 'Минина', 'Машиностроителей', 'Детская', 'ДОС',
        'Тюленина', 'Запорожская', 'Дальневосточная', 'Громова', 'О.Кошевого',
        'Балтийская', 'Р.Люксембург', 'Февральская', 'Толбухина', 'Лунная',
        'Дарвина', 'З.Космодемьянской', 'Высотная', 'Рязанская', 'Малиновая',
    )

    city_names = (
        'Абакан', 'Абинск', 'Агата', 'Агинское (Забайк.)', 'Адлер', 'Адыгейск',
        'Азов (Рост.)', 'Алагир', 'Алапаевск', 'Алдан', 'Александров',
        'Александров Гай', 'Александровск', 'Александровск-Сахалинский',
        'Алексин', 'Амдерма', 'Амурск', 'Анадырь', 'Анапа', 'Ангарск',
        'Андреаполь', 'Анива', 'Апатиты', 'Апрелевка', 'Апшеронск', 'Аргаяш',
        'Ардон', 'Арзамас', 'Армавир', 'Арсеньев', 'Артем', 'Архангельск',
        'Архыз', 'Аршан (Бурят.)', 'Асбест', 'Асино', 'Астрахань', 'Ахтубинск',
        'Ачинск', 'Ачхой Мартан', 'Аша', 'Бавлы', 'Байкальск', 'Баксан',
        'Балашиха', 'Балашов', 'Балтийск', 'Баргузин', 'Барнаул', 'Батайск',
        'Белгород', 'Белогорск (Амур.)', 'Белокуриха', 'Беломорск', 'Белорецк',
        'Белореченск', 'Белоярский', 'Белый Яр (Томск.)', 'Березники',
        'Беслан', 'Бийск', 'Билибино', 'Биробиджан', 'Бирск',
        'Благовещенск (Амур.)', 'Богучар', 'Бодайбо', 'Бологое', 'Бомнак',
        'Борзя', 'Боровск', 'Братск', 'Бреды', 'Бронницы', 'Брянск',
        'Бугульма', 'Бугуруслан', 'Буденновск', 'Бузулук', 'Буйнакск',
        'Быково (метеост.)', 'Валаам', 'Валдай', 'Ведено', 'Великие Луки',
        'Великий Устюг', 'Вендинга', 'Верещагино (Перм.)', 'Верхнее Пенжино',
        'Верхний Баскунчак', 'Верхний Тагил', 'Верхний Уфалей', 'Верхотурье',
        'Верхоянск', 'Видное', 'Вилюйск', 'Витим', 'Владивосток',
        'Владикавказ', 'Владимир', 'Внуково (метеост.)', 'Волгоград',
        'Волгодонск', 'Вологда', 'Волоколамск', 'Волхов', 'Воркута',
        'Воронеж', 'Воскресенск', 'Воткинск', 'Всеволожск', 'Вуктыл', 'Выборг',
        'Вытегра', 'Вязьма', 'Гаврилов-Ям', 'Гагарин', 'Галич', 'Гатчина',
        'Гдов', 'Геленджик', 'Глазов', 'Голицыно', 'Горно-Алтайск',
        'Городовиковск', 'Горячий Ключ', 'Горячинск', 'Гремячинск (Бурят.)',
        'Гремячинск (Перм.)', 'Грозный', 'Губаха', 'Губкин', 'Губкинский',
        'Гудермес', 'Гусь-Хрустальный', 'Дагомыс', 'Далматово', 'Данков',
        'Двинской', 'Дербент', 'Джейрах', 'Джубга', 'Дзержинск', 'Дивногорск',
        'Диксон', 'Дмитров', 'Дно', 'Добрянка', 'Долинск', 'Домбай',
        'Домодедово', 'Дубна', 'Дудинка', 'Егорьевск', 'Ейск', 'Екатеринбург',
        'Елабуга', 'Елатьма', 'Елец', 'Ельня', 'Енисейск', 'Ербогачен',
        'Ершов', 'Ессентуки', 'Железногорск(Курск.)', 'Жиганск', 'Жигулевск',
        'Жуковский', 'Забайкальск', 'Заводоуковск', 'Завьялиха', 'Зарайск',
        'Звенигород', 'Зеленогорск (Ленин.)', 'Зеленоград', 'Златоуст',
        'Змеиногорск', 'Иваново', 'Ивдель', 'Игарка', 'Игнашино', 'Ижевск',
        'Избербаш', 'Инта', 'Ирбит', 'Иркутск', 'Истра', 'Ишим', 'Йошкар-Ола',
        'Кабанск', 'Кажим', 'Казань', 'Калач', 'Калач-на-Дону', 'Калачинск',
        'Калевала', 'Калининград', 'Калуга', 'Калязин', 'Каменномостский',
        'Каменск-Уральский', 'Каменск-Шахтинский', 'Камень-на-Оби', 'Камышин',
        'Камышлов', 'Кандалакша', 'Каневская', 'Канск', 'Карабудахкент',
        'Карабулак', 'Карачаевск', 'Каргасок', 'Каргополь', 'Карпинск',
        'Карталы', 'Касимов', 'Каспийск', 'Катав-Ивановск', 'Катайск',
        'Качканар', 'Кашира', 'Кашхатау', 'Кедровый', 'Кежма', 'Кемерово',
        'Кетченеры', 'Кижи', 'Кизел', 'Кизилюрт', 'Кизляр', 'Кимры',
        'Кингисепп', 'Кинешма', 'Киренск', 'Киржач', 'Кириши', 'Киров (Вятка)',
        'Кирово-Чепецк', 'Кировск (Мурм.)', 'Кировск (Ленин.)', 'Кисловодск',
        'Клин', 'Ковров', 'Когалым', 'Коломна', 'Колпашево',
        'Комсомольск-на-Амуре', 'Кондопога', 'Королев', 'Корсаков',
        'Костомукша', 'Кострома', 'Котельнич', 'Котлас', 'Кош-Агач',
        'Красная Поляна', 'Красновишерск', 'Красногорск (Моск.)', 'Краснодар',
        'Краснокамск', 'Красноселькуп', 'Краснотурьинск', 'Красноуральск',
        'Красноуфимск', 'Красноярск', 'Кропоткин (Краснод.)', 'Крымск',
        'Кудымкар', 'Кузнецк', 'Кулу', 'Кулунда', 'Кунгур', 'Курган',
        'Курганинск', 'Курильск', 'Курск', 'Куртамыш', 'Курумкан', 'Курчатов',
        'Кущевская', 'Кызыл', 'Кырен', 'Кыштым', 'Кяхта', 'Лабинск',
        'Лабытнанги', 'Лагань', 'Лазаревское', 'Лесной (Сверд.)', 'Липецк',
        'Листвянка (Иркут.)', 'Лодейное Поле', 'Лотошино', 'Луга', 'Луховицы',
        'Лысьва', 'Льгов', 'Любань', 'Люберцы', 'Лянтор', 'Магадан', 'Магас',
        'Магнитогорск', 'Майкоп', 'Макаров', 'Макушино', 'Малая Вишера',
        'Малгобек', 'Малоярославец', 'Махачкала', 'Медногорск',
        'Междуреченский', 'Мезень', 'Мелеуз', 'Меренга', 'Миасс',
        'Миллерово', 'Минеральные Воды', 'Минусинск', 'Мирный', 'Мичуринск',
        'Можайск', 'Можга', 'Моздок', 'Мокшан', 'Мончегорск', 'Морозовск',
        'Моршанск', 'Москва', 'Москва, МГУ', 'Мостовской', 'Муравленко',
        'Мураши', 'Мурманск', 'Муром', 'Мценск', 'Мыс Шмидта', 'Мытищи',
        'Набережные Челны', 'Надым', 'Назрань', 'Нальчик', 'Наро-Фоминск',
        'Нарткала', 'Нарым', 'Нарьян-Мар', 'Находка', 'Невельск',
        'Невинномысск', 'Невьянск', 'Неплюевка', 'Нерчинск', 'Нефедова',
        'Нефтегорск (Самар.)', 'Нефтекамск', 'Нефтеюганск', 'Нижневартовск',
        'Нижнекамск', 'Нижнеудинск', 'Нижний Новгород', 'Нижний Тагил',
        'Новая Игирма', 'Новгород Великий', 'Новокузнецк', 'Новомичуринск',
        'Новомосковск', 'Новороссийка', 'Новороссийск', 'Новосибирск',
        'Новочеркасск', 'Новый Оскол', 'Новый Уренгой', 'Ногинск (Моск.)',
        'Ноглики', 'Норильск', 'Ноябрьск', 'Нурлат', 'Нягань', 'Нязепетровск',
        'Обнинск', 'Обоянь', 'Объячево', 'Одинцово', 'Озеры', 'Оймякон',
        'Октябрьский (Башк.)', 'Октябрьское (Хант.)', 'Октябрьское (Челяб.)',
        'Оленегорск (Якут.)', 'Оленек', 'Омск', 'Онега', 'Орел', 'Оренбург',
        'Орехово-Зуево', 'Орск', 'Оса', 'Осташков', 'Оха', 'Охотск',
        'Павловская', 'Павловский Посад', 'Палана', 'Партизанск', 'Певек',
        'Пенза', 'Переславль-Залесский', 'Пермь', 'Петрозаводск',
        'Петропавловск-Камчатский', 'Петухово', 'Петушки', 'Печенга', 'Печора',
        'Пинега', 'Плес', 'Плесецк', 'Подольск', 'Поронайск', 'Поярково',
        'Приморско-Ахтарск', 'Приозерск', 'Прохладный', 'Псебай', 'Псков',
        'Пушкин', 'Пушкино (Моск.)', 'Пушкинские Горы', 'Пышма', 'Пятигорск',
        'Радужный', 'Раменское', 'Ребриха', 'Ревда (Сверд.)', 'Ржев',
        'Рославль', 'Россошь', 'Ростов', 'Ростов-на-Дону', 'Рубцовск', 'Руза',
        'Рыбинск', 'Рыльск', 'Ряжск', 'Рязань', 'Салават', 'Салехард',
        'Сальск', 'Самара', 'Санкт-Петербург', 'Саранск', 'Сарапул', 'Саратов',
        'Саров (Морд.)', 'Сасово', 'Саянск', 'Светлогорск (Калин.)',
        'Северо-Курильск', 'Северобайкальск', 'Северодвинск', 'Североморск',
        'Североуральск', 'Сеймчан', 'Семлячики', 'Серафимович',
        'Сергиев Посад', 'Серебряные Пруды', 'Середниково', 'Серов',
        'Серпухов', 'Сибай', 'Сковородино', 'Славгород', 'Славянск-на-Кубани',
        'Сладково', 'Слюдянка', 'Смирных', 'Смоленск', 'Снежинск',
        'Снежногорск (Мурм.)', 'Соболево', 'Советский', 'Соликамск',
        'Солнечногорск', 'Соловки', 'Соль-Илецк', 'Сорочинск', 'Сортавала',
        'Сосновый Бор', 'Сосногорск', 'Сосьва (Хант.)', 'Сочи', 'Ставрополь',
        'Старая Русса', 'Старый Оскол', 'Стерлитамак', 'Стрежевой', 'Ступино',
        'Суздаль', 'Сузун', 'Сунтар', 'Сургут (Хант.)', 'Сусуман', 'Сухиничи',
        'Сызрань', 'Сыктывкар', 'Тавда', 'Таганрог', 'Тайшет', 'Талдом',
        'Тамбей', 'Тамбов', 'Тарко-Сале', 'Таштагол', 'Тверь', 'Теберда',
        'Темрюк', 'Териберка', 'Терней', 'Терскол', 'Тикси', 'Тимашевск',
        'Тихвин', 'Тихорецк', 'Тобольск', 'Токма', 'Токсово', 'Тольятти',
        'Томари', 'Томпа', 'Томск', 'Торжок', 'Тосно', 'Тотьма',
        'Троицк (Челяб.)', 'Троицк (Моск.)', 'Троицко-Печорск', 'Туапсе',
        'Тула', 'Тулпан', 'Тулун', 'Тура', 'Туруханск', 'Тутаев', 'Тутончаны',
        'Тымовское', 'Тында', 'Тырныауз', 'Тюмень', 'Уварово', 'Углегорск',
        'Углич', 'Улан-Удэ', 'Ульяновск', 'Урай', 'Уренгой', 'Урус-Мартан',
        'Урюпинск', 'Усинск', 'Усмань', 'Усолье Сибирское', 'Уссурийск',
        'Усть-Баргузин', 'Усть-Джегута', 'Усть-Илимск', 'Усть-Ишим',
        'Усть-Калманка', 'Усть-Камчатск', 'Усть-Катав', 'Усть-Кулом',
        'Усть-Кут', 'Усть-Ордынский', 'Устюжна', 'Уфа', 'Ухта', 'Учалы',
        'Уэлен', 'Фатеж', 'Хабаровск', 'Ханты-Мансийск', 'Хасавюрт',
        'Хасан', 'Хатанга', 'Химки', 'Холмогоры', 'Холмск', 'Хоста',
        'Хужир', 'Цимлянск', 'Чайковский', 'Чебаркуль', 'Чебоксары',
        'Чегем', 'Челюскин', 'Челябинск', 'Черемхово', 'Череповец',
        'Черкесск', 'Чермоз', 'Черняховск', 'Черский', 'Черусти', 'Чехов',
        'Чикола', 'Чита', 'Чокурдах', 'Чулым', 'Чусовой', 'Шадринск', 'Шали',
        'Шамары', 'Шарья', 'Шатки', 'Шатой', 'Шатура', 'Шаховская', 'Шахты',
        'Шелагонцы', 'Шелехов', 'Шенкурск', 'Шерегеш', 'Шереметьево', 'Шилка',
        'Шумиха', 'Шуя', 'Щелково', 'Щельяюр', 'Элиста', 'Эльбрус', 'Эльтон',
        'Энгельс', 'Югорск', 'Южно-Курильск', 'Южно-Сахалинск', 'Южноуральск',
        'Юровск', 'Юрьев-Польский', 'Юрьевец (Иван.)', 'Юрюзань', 'Якутск',
        'Якша', 'Ялуторовск', 'Ямбург', 'Яр-Сале', 'Ярославль',
        'Ясный (Оренб.)', 'Яхрома', 'Яшалта', 'Яшкуль',
    )

    def city_prefix(self):
        return self.random_element(self.city_prefixes)

    def city_name(self):
        return self.random_element(self.city_names)

    def street_title(self):
        return self.random_element(self.street_titles)



from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}')

    prefixes_male = (
        "GEN", "LT GEN", "MAJ GEN", "COL", "LT COL", "MAJ", "CAPT", "LT", "SUB LT",
        "S M 1",
        "S M 2", "S M 3", "SGT", "CPL", "PFC", "PVT", "ADM", "V ADM", "R ADM", "CAPT",
        "CDR",
        "L CDR", "LT", "LT JG", "SUB LT", "CPO 1", "CPO 2", "CPO 3", "PO 1", "PO 2",
        "PO 3",
        "SEA-MAN", "ACM", "AM", "AVM", "GP CAPT", "WG CDR", "SQN LDR", "FLT LT",
        "FLG OFF",
        "PLT OFF", "FS 1", "FS 2", "FS 3", "SGT", "CPL", "LAC", "AMN", "POL GEN",
        "POL LT GEN", "POL MAJ GEN", "POL COL", "POL LT COL", "POL MAJ", "POL CAPT",
        "POL LT",
        "POL SUB LT", "POL SEN SGT MAJ", "POL SGT MAJ", "POL SGT", "POL CPL", "POL L/C",
        "POL CONST", "MR", "REV", "M L", "M R", "SAMANERA", "PHRA",
        "PHRA ATHIKAN", "CHAO ATHIKAN", "PHRAPALAD", "PHRASAMU", "PHRABAIDIKA",
        "PHRAKHU PALAD", "PHRAKHU SAMU", "PHRAKHU BAIDIKA", "PHRAMAHA",
        "PHRAKHU DHAMMADHORN",
        "PHRAKHU VINAIDHORN")

    prefixes_female = (
        "GEN",
        "LT GEN",
        "MAJ GEN",
        "COL",
        "LT COL",
        "MAJ",
        "CAPT",
        "LT",
        "SUB LT",
        "S M 1",
        "S M 2",
        "S M 3",
        "SGT",
        "CPL",
        "PFC",
        "PVT",
        "ADM",
        "V ADM",
        "R ADM",
        "CAPT",
        "CDR",
        "L CDR",
        "LT",
        "LT JG",
        "SUB LT",
        "CPO 1",
        "CPO 2",
        "CPO 3",
        "PO 1",
        "PO 2",
        "PO 3",
        "SEA-MAN",
        "ACM",
        "AM",
        "AVM",
        "GP CAPT",
        "WG CDR",
        "SQN LDR",
        "FLT LT",
        "FLG OFF",
        "PLT OFF",
        "FS 1",
        "FS 2",
        "FS 3",
        "SGT",
        "CPL",
        "LAC",
        "AMN",
        "POL GEN",
        "POL LT GEN",
        "POL MAJ GEN",
        "POL COL",
        "POL LT COL",
        "POL MAJ",
        "POL CAPT",
        "POL LT",
        "POL SUB LT",
        "POL SEN SGT MAJ",
        "POL SGT MAJ",
        "POL SGT",
        "POL CPL",
        "POL L/C",
        "POL CONST",
        "MRS",
        "MISS",
        "REV",
        "M L")

    prefixes = prefixes_male + prefixes_female

    first_names = (
        "Pornchanok",
        "Patchaploy",
        "Peem",
        "Kodchaporn",
        "Pattapon",
        "Sarunporn",
        "Jinjuta",
        "Sorawut",
        "Suvakit",
        "Prima",
        "Darin",
        "Pintusorn",
        "Kulnun",
        "Nutcha",
        "Nutkrita",
        "Sittikorn",
        "Wasin",
        "Apisara",
        "Nattawun",
        "Tunradee",
        "Niracha",
        "Tunchanok",
        "Kamolchanok",
        "Jaruwan",
        "Pachongruk",
        "Pakjira",
        "Pattatomporn",
        "Suwijuk",
        "Noppakao",
        "Ratchanon",
        "Atit",
        "Kunaporn",
        "Arisara",
        "Todsawun",
        "Chaiwut",
        "Puntira",
        "Supasita",
        "Patcharaporn",
        "Phubes",
        "Pattamon",
        "Chanya",
        "Pannawich",
        "Chawin",
        "Pada",
        "Chanikan",
        "Nutwadee",
        "Chalisa",
        "Prames",
        "Supasit",
        "Sitiwat",
        "Teetat",
        "Yada",
        "Phenphitcha",
        "Anon",
        "Chaifah",
        "Pawan",
        "Aunyaporn",
        "Yanisa",
        "Pak",
        "Chayanin",
        "Chayapat",
        "Jitrin",
        "Wassaya",
        "Pitipat",
        "Nichakarn",
        "Parin",
        "Thanatcha",
    )

    last_names = (
        "Prachayaroch", "Prachayaroch", "Kamalanon", "Tianvarich", "Bunlerngsri",
        "Sukhenai",
        "Posalee", "Chaisatit", "Sujjaboriboon", "Kamalanon", "Neerachapong",
        "Pianduangsri",
        "Pasuk", "Losatapornpipit", "Suraprasert", "Matinawin", "Choeychuen", "Wasunun",
        "Kumsoontorn", "Sireelert", "Boonpungbaramee", "Sorattanachai", "Benchapatranon",
        "Intaum", "Pikatsingkorn", "Srisoontorn", "Polpo", "Kongchayasukawut",
        "Charoensuksopol", "Bunlupong", "Chomsri", "Tungkasethakul", "Chowitunkit",
        "Todsapornpitakul", "Wimolnot", "Kittakun", "Methavorakul", "Pitanuwat",
        "Phusilarungrueng", "Turongkinanon", "Kitprapa", "Pothanun", "Youprasert",
        "Methavorakul", "Vethayasas", "Sooksawang", "Anekvorakul", "Pichpandecha",
        "Sittisaowapak", "Suraprachit", "Kongsri", "Trikasemmart", "Habpanom",
        "Wannapaitoonsri", "Vinyuvanichkul", "Pongpanitch", "Permchart", "Chaihirankarn",
        "Thantananont", "Norramon", "Prayoonhong", "Lertsattayanusak", "Polauaypon",
        "Prakalpawong", "Titipatrayunyong", "Krittayanukoon", "Siripaiboo")



# coding=utf-8
from __future__ import unicode_literals

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_connector = ''
    sentence_punctuation = '。'
    word_list = (
        u'コミュニティ',
        u'隠す',
        u'葉',
        u'陶器',
        u'錯覚',
        u'バーゲン',
        u'リニア',
        u'コーラス',
        u'仕上げ',
        u'叔父',
        u'移動',
        u'差別する',
        u'極端な',
        u'数字',
        u'テント',
        u'必要',
        u'主人',
        u'電池',
        u'ソース',
        u'野球',
        u'ストレージ',
        u'スキーム',
        u'暖かい',
        u'ささやき',
        u'器官',
        u'トリビュート',
        u'同行',
        u'ジャム',
        u'パン',
        u'索引',
        u'トス',
        u'織る',
        u'パーセント',
        u'拡張',
        u'教授',
        u'バスケット',
        u'創傷',
        u'フレーム',
        u'明らかにする',
        u'フェミニスト',
        u'発生する',
        u'怒り',
        u'ボトル',
        u'狐',
        u'柔らかい',
        u'リフト',
        u'バス',
        u'雪',
        u'画面',
        u'パイオニア',
        u'マリン',
        u'ダイヤモンド',
        u'普通の',
        u'意図',
        u'ヘア',
        u'日曜日',
        u'プラスチック',
        u'衝突',
        u'評議会',
        u'主婦',
        u'保証金',
        u'動物',
        u'参加する',
        u'教会',
        u'コミュニケーション',
        u'憲法',
        u'本質的な',
        u'探査',
        u'呼ぶ',
        u'供給',
        u'スペル',
        u'再現する',
        u'合計',
        u'ダッシュ',
        u'擁する',
        u'知覚',
        u'シェービング',
        u'コンペ',
        u'オークション',
        u'細かい',
        u'ニュース',
        u'癌',
        u'トーン',
        u'チーズ',
        u'反射',
        u'ブランチ',
        u'コピー',
        u'状況',
        u'スマッシュ',
        u'式',
        u'協力',
        u'管理する',
        u'文言',
        u'編組',
        u'ジャーナル',
        u'腐った',
        u'見落とす',
        u'ハードウェア',
        u'ピック',
        u'感謝する',
        u'楽しんで',
        u'人形',
        u'建築',
        u'見出し',
        u'タワー',
        u'ホイール',
        u'省略',
        u'ログ',
        u'助けて',
        u'不自然な',
        u'出演者',
        u'転倒',
        u'運',
        u'障害',
        u'クルー',
        u'追放する',
        u'月',
        u'カレッジ',
        u'緩む',
        u'分割',
        u'欠乏',
        u'通行料金',
        u'電話',
        u'狭い',
        u'中央',
        u'埋め込む',
        u'革新',
        u'ブレーキ',
        u'コーナー',
        u'溝',
        u'脊椎',
        u'ブラケット',
        u'戦略的',
        u'尿',
        u'血まみれの',
        u'尊敬する',
        u'催眠術',
        u'アクセルペダル',
        u'厳しい',
        u'サンプル',
        u'奨励します',
        u'指名',
        u'クール',
        u'クロス',
        u'ヒール',
        u'敵対的な',
        u'近代化する',
        u'部隊',
        u'目的',
        u'保持する',
        u'中世',
        u'デッド',
        u'ノート',
        u'デフォルト',
        u'犯罪者',
        u'キャビン',
        u'副',
        u'改善',
        u'職人',
        u'シュガー',
        u'花嫁',
        u'倫理',
        u'偏差',
        u'販売',
        u'軸',
        u'サラダ',
        u'品質',
        u'風景',
        u'虐待',
        u'立派な',
        u'ベルベット',
        u'ハンマー',
        u'キャビネット',
        u'トレーナー',
        u'リハビリ',
        u'サワー',
        u'連続',
        u'学生',
        u'高い',
        u'賞賛する',
        u'行進',
        u'ダニ',
        u'証言する',
        u'符号',
        u'バナー',
        u'バケツ',
        u'カラム',
        u'装置',
        u'ヒット',
        u'敵',
        u'トースト',
        u'試してみる',
        u'大統領',
        u'屋根裏',
        u'メニュー',
        u'残る',
        u'リンク',
        u'舗装',
        u'インチ',
        u'特徴',
        u'は',
        u'持つ',
        u'持っていました',
        u'あった',
        u'〜',
        u'ない',
        u'今',
        u'今日',
        u'持ってる',
        u'午前',
        u'私',
        u'君は',
        u'彼',
        u'彼女',
        u'それ',
        u'自体',
        u'あなた自身',
        u'じぶんの',
        u'鉱山',
    )
